# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import SVResampleTask


def test_SVResampleTask_inputs():
    input_map = dict(
        align=dict(argstr='-align %s', ),
        args=dict(argstr='%s', ),
        array_size=dict(
            argstr='-size %d %d %d',
            xor=['target_file'],
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-in %s',
            extensions=None,
            mandatory=True,
        ),
        origin=dict(
            argstr='-origin %g %g %g',
            xor=['target_file'],
        ),
        out_file=dict(
            argstr='-out %s',
            extensions=None,
            keep_extension=True,
            name_source='in_file',
            name_template='%s_resampled',
        ),
        target_file=dict(
            argstr='-target %s',
            extensions=None,
            xor=['array_size', 'voxel_size', 'origin'],
        ),
        voxel_size=dict(
            argstr='-vsize %g %g %g',
            xor=['target_file'],
        ),
    )
    inputs = SVResampleTask.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SVResampleTask_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = SVResampleTask.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utilities import HistogramMatchingFilter


def test_HistogramMatchingFilter_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        histogramAlgorithm=dict(argstr='--histogramAlgorithm %s', ),
        inputBinaryVolume=dict(
            argstr='--inputBinaryVolume %s',
            extensions=None,
        ),
        inputVolume=dict(
            argstr='--inputVolume %s',
            extensions=None,
        ),
        numberOfHistogramBins=dict(argstr='--numberOfHistogramBins %d', ),
        numberOfMatchPoints=dict(argstr='--numberOfMatchPoints %d', ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
        referenceBinaryVolume=dict(
            argstr='--referenceBinaryVolume %s',
            extensions=None,
        ),
        referenceVolume=dict(
            argstr='--referenceVolume %s',
            extensions=None,
        ),
        verbose=dict(argstr='--verbose ', ),
        writeHistogram=dict(argstr='--writeHistogram %s', ),
    )
    inputs = HistogramMatchingFilter.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_HistogramMatchingFilter_outputs():
    output_map = dict(outputVolume=dict(extensions=None, ), )
    outputs = HistogramMatchingFilter.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..segmentation import CorticalThickness


def test_CorticalThickness_inputs():
    input_map = dict(
        anatomical_image=dict(
            argstr='-a %s',
            extensions=None,
            mandatory=True,
        ),
        args=dict(argstr='%s', ),
        b_spline_smoothing=dict(argstr='-v', ),
        brain_probability_mask=dict(
            argstr='-m %s',
            copyfile=False,
            extensions=None,
            mandatory=True,
        ),
        brain_template=dict(
            argstr='-e %s',
            extensions=None,
            mandatory=True,
        ),
        cortical_label_image=dict(extensions=None, ),
        debug=dict(argstr='-z 1', ),
        dimension=dict(
            argstr='-d %d',
            usedefault=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        extraction_registration_mask=dict(
            argstr='-f %s',
            extensions=None,
        ),
        image_suffix=dict(
            argstr='-s %s',
            usedefault=True,
        ),
        keep_temporary_files=dict(argstr='-k %d', ),
        label_propagation=dict(argstr='-l %s', ),
        max_iterations=dict(argstr='-i %d', ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_prefix=dict(
            argstr='-o %s',
            usedefault=True,
        ),
        posterior_formulation=dict(argstr='-b %s', ),
        prior_segmentation_weight=dict(argstr='-w %f', ),
        quick_registration=dict(argstr='-q 1', ),
        segmentation_iterations=dict(argstr='-n %d', ),
        segmentation_priors=dict(
            argstr='-p %s',
            mandatory=True,
        ),
        t1_registration_template=dict(
            argstr='-t %s',
            extensions=None,
            mandatory=True,
        ),
        use_floatingpoint_precision=dict(argstr='-j %d', ),
        use_random_seeding=dict(argstr='-u %d', ),
    )
    inputs = CorticalThickness.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_CorticalThickness_outputs():
    output_map = dict(
        BrainExtractionMask=dict(extensions=None, ),
        BrainSegmentation=dict(extensions=None, ),
        BrainSegmentationN4=dict(extensions=None, ),
        BrainSegmentationPosteriors=dict(),
        BrainVolumes=dict(extensions=None, ),
        CorticalThickness=dict(extensions=None, ),
        CorticalThicknessNormedToTemplate=dict(extensions=None, ),
        ExtractedBrainN4=dict(extensions=None, ),
        SubjectToTemplate0GenericAffine=dict(extensions=None, ),
        SubjectToTemplate1Warp=dict(extensions=None, ),
        SubjectToTemplateLogJacobian=dict(extensions=None, ),
        TemplateToSubject0Warp=dict(extensions=None, ),
        TemplateToSubject1GenericAffine=dict(extensions=None, ),
    )
    outputs = CorticalThickness.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""This module provides interfaces for workbench surface commands"""
from __future__ import (print_function, division, unicode_literals,
                        absolute_import)
import os

from ..base import (TraitedSpec, File, traits, CommandLineInputSpec)
from .base import WBCommand
from ... import logging

iflogger = logging.getLogger('nipype.interface')


class MetricResampleInputSpec(CommandLineInputSpec):
    in_file = File(
        exists=True,
        mandatory=True,
        argstr="%s",
        position=0,
        desc="The metric file to resample")
    current_sphere = File(
        exists=True,
        mandatory=True,
        argstr="%s",
        position=1,
        desc="A sphere surface with the mesh that the metric is currently on")
    new_sphere = File(
        exists=True,
        mandatory=True,
        argstr="%s",
        position=2,
        desc="A sphere surface that is in register with <current-sphere> and"
             " has the desired output mesh")
    method = traits.Enum(
        "ADAP_BARY_AREA",
        "BARYCENTRIC",
        argstr="%s",
        mandatory=True,
        position=3,
        desc="The method name - ADAP_BARY_AREA method is recommended for"
             " ordinary metric data, because it should use all data while"
             " downsampling, unlike BARYCENTRIC. If ADAP_BARY_AREA is used,"
             " exactly one of area_surfs or area_metrics must be specified")
    out_file = File(
        name_source=["new_sphere"],
        name_template="%s.out",
        keep_extension=True,
        argstr="%s",
        position=4,
        desc="The output metric")
    area_surfs = traits.Bool(
        position=5,
        argstr="-area-surfs",
        xor=["area_metrics"],
        desc="Specify surfaces to do vertex area correction based on")
    area_metrics = traits.Bool(
        position=5,
        argstr="-area-metrics",
        xor=["area_surfs"],
        desc="Specify vertex area metrics to do area correction based on")
    current_area = File(
        exists=True,
        position=6,
        argstr="%s",
        desc="A relevant anatomical surface with <current-sphere> mesh OR"
             " a metric file with vertex areas for <current-sphere> mesh")
    new_area = File(
        exists=True,
        position=7,
        argstr="%s",
        desc="A relevant anatomical surface with <current-sphere> mesh OR"
             " a metric file with vertex areas for <current-sphere> mesh")
    roi_metric = File(
        exists=True,
        position=8,
        argstr="-current-roi %s",
        desc="Input roi on the current mesh used to exclude non-data vertices")
    valid_roi_out = traits.Bool(
        position=9,
        argstr="-valid-roi-out",
        desc="Output the ROI of vertices that got data from valid source vertices")
    largest = traits.Bool(
        position=10,
        argstr="-largest",
        desc="Use only the value of the vertex with the largest weight")


class MetricResampleOutputSpec(TraitedSpec):
    out_file = File(exists=True, desc="the output metric")
    roi_file = File(desc="ROI of vertices that got data from valid source vertices")


class MetricResample(WBCommand):
    """
    Resample a metric file to a different mesh

    Resamples a metric file, given two spherical surfaces that are in
    register.  If ``ADAP_BARY_AREA`` is used, exactly one of -area-surfs or
    ``-area-metrics`` must be specified.

    The ``ADAP_BARY_AREA`` method is recommended for ordinary metric data,
    because it should use all data while downsampling, unlike ``BARYCENTRIC``.
    The recommended areas option for most data is individual midthicknesses
    for individual data, and averaged vertex area metrics from individual
    midthicknesses for group average data.

    The ``-current-roi`` option only masks the input, the output may be slightly
    dilated in comparison, consider using ``-metric-mask`` on the output when
    using ``-current-roi``.

    The ``-largest option`` results in nearest vertex behavior when used with
    ``BARYCENTRIC``.  When resampling a binary metric, consider thresholding at
    0.5 after resampling rather than using ``-largest``.

    >>> from nipype.interfaces.workbench import MetricResample
    >>> metres = MetricResample()
    >>> metres.inputs.in_file = 'sub-01_task-rest_bold_space-fsaverage5.L.func.gii'
    >>> metres.inputs.method = 'ADAP_BARY_AREA'
    >>> metres.inputs.current_sphere = 'fsaverage5_std_sphere.L.10k_fsavg_L.surf.gii'
    >>> metres.inputs.new_sphere = 'fs_LR-deformed_to-fsaverage.L.sphere.32k_fs_LR.surf.gii'
    >>> metres.inputs.area_metrics = True
    >>> metres.inputs.current_area = 'fsaverage5.L.midthickness_va_avg.10k_fsavg_L.shape.gii'
    >>> metres.inputs.new_area = 'fs_LR.L.midthickness_va_avg.32k_fs_LR.shape.gii'
    >>> metres.cmdline
    'wb_command -metric-resample sub-01_task-rest_bold_space-fsaverage5.L.func.gii \
    fsaverage5_std_sphere.L.10k_fsavg_L.surf.gii \
    fs_LR-deformed_to-fsaverage.L.sphere.32k_fs_LR.surf.gii \
    ADAP_BARY_AREA fs_LR-deformed_to-fsaverage.L.sphere.32k_fs_LR.surf.out \
    -area-metrics fsaverage5.L.midthickness_va_avg.10k_fsavg_L.shape.gii \
    fs_LR.L.midthickness_va_avg.32k_fs_LR.shape.gii'
    """
    input_spec = MetricResampleInputSpec
    output_spec = MetricResampleOutputSpec
    _cmd = 'wb_command -metric-resample'

    def _format_arg(self, opt, spec, val):
        if opt in ['current_area', 'new_area']:
            if not self.inputs.area_surfs and not self.inputs.area_metrics:
                raise ValueError("{} was set but neither area_surfs or"
                                 " area_metrics were set".format(opt))
        if opt == "method":
            if (val == "ADAP_BARY_AREA" and
                    not self.inputs.area_surfs and
                    not self.inputs.area_metrics):
                raise ValueError("Exactly one of area_surfs or area_metrics"
                                 " must be specified")
        if opt == "valid_roi_out" and val:
            # generate a filename and add it to argstr
            roi_out = self._gen_filename(self.inputs.in_file, suffix='_roi')
            iflogger.info("Setting roi output file as", roi_out)
            spec.argstr += " " + roi_out
        return super(MetricResample, self)._format_arg(opt, spec, val)

    def _list_outputs(self):
        outputs = super(MetricResample, self)._list_outputs()
        if self.inputs.valid_roi_out:
            roi_file = self._gen_filename(self.inputs.in_file, suffix='_roi')
            outputs['roi_file'] = os.path.abspath(roi_file)
        return outputs



#!/usr/bin/env python
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""Script to auto-generate interface docs.
"""
from __future__ import print_function, unicode_literals
# stdlib imports
import os
import sys

# *****************************************************************************
if __name__ == '__main__':
    nipypepath = os.path.abspath('..')
    sys.path.insert(1, nipypepath)
    # local imports
    from interfacedocgen import InterfaceHelpWriter
    package = 'nipype'
    outdir = os.path.join('interfaces', 'generated')
    docwriter = InterfaceHelpWriter(package)
    # Packages that should not be included in generated API docs.
    docwriter.package_skip_patterns += [
        '\.external$',
        '\.fixes$',
        '\.utils$',
        '\.pipeline',
        '\.testing',
        '\.caching',
        '\.scripts',
    ]
    # Modules that should not be included in generated API docs.
    docwriter.module_skip_patterns += [
        '\.version$',
        '\.interfaces\.base$',
        '\.interfaces\.matlab$',
        '\.interfaces\.rest$',
        '\.interfaces\.pymvpa$',
        '\.interfaces\.slicer\.generate_classes$',
        '\.interfaces\.spm\.base$',
        '\.interfaces\.traits',
        '\.pipeline\.alloy$',
        '\.pipeline\.s3_node_wrapper$',
        '\.testing',
        '\.scripts',
        '\.conftest',
    ]
    docwriter.class_skip_patterns += [
        'AFNICommand',
        'ANTS',
        'FSLCommand',
        'FS',
        'Info',
        '^SPM',
        'Tester',
        'Spec$',
        'Numpy'
        # NipypeTester raises an
        # exception when instantiated in
        # InterfaceHelpWriter.generate_api_doc
        'NipypeTester',
    ]
    docwriter.write_api_docs(outdir)
    docwriter.write_index(outdir, 'gen', relative_to='interfaces')
    print('%d files written' % len(docwriter.written_modules))



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
import os

import nipype.interfaces.spm.model as spm
import nipype.interfaces.matlab as mlab

mlab.MatlabCommand.set_default_matlab_cmd(os.getenv('MATLABCMD', 'matlab'))


def test_level1design():
    assert spm.Level1Design._jobtype == 'stats'
    assert spm.Level1Design._jobname == 'fmri_spec'


def test_estimatemodel():
    assert spm.EstimateModel._jobtype == 'stats'
    assert spm.EstimateModel._jobname == 'fmri_est'


def test_estimatecontrast():
    assert spm.EstimateContrast._jobtype == 'stats'
    assert spm.EstimateContrast._jobname == 'con'


def test_threshold():
    assert spm.Threshold._jobtype == 'basetype'
    assert spm.Threshold._jobname == 'basename'


def test_factorialdesign():
    assert spm.FactorialDesign._jobtype == 'stats'
    assert spm.FactorialDesign._jobname == 'factorial_design'


def test_onesamplettestdesign():
    assert spm.OneSampleTTestDesign._jobtype == 'stats'
    assert spm.OneSampleTTestDesign._jobname == 'factorial_design'


def test_twosamplettestdesign():
    assert spm.TwoSampleTTestDesign._jobtype == 'stats'
    assert spm.TwoSampleTTestDesign._jobname == 'factorial_design'



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""Top-level namespace for spm."""

from .base import (Info, SPMCommand, logger, no_spm, scans_for_fname,
                   scans_for_fnames)
from .preprocess import (FieldMap, SliceTiming, Realign, RealignUnwarp,
                         Coregister, Normalize, Normalize12, Segment,
                         Smooth, NewSegment, DARTEL, DARTELNorm2MNI,
                         CreateWarped, VBMSegment)
from .model import (Level1Design, EstimateModel, EstimateContrast, Threshold,
                    OneSampleTTestDesign, TwoSampleTTestDesign,
                    PairedTTestDesign, MultipleRegressionDesign)
from .utils import (Analyze2nii, CalcCoregAffine, ApplyTransform, Reslice,
                    ApplyInverseDeformation, ResliceToReference, DicomImport)



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..model import EstimateContrast


def test_EstimateContrast_inputs():
    input_map = dict(
        axis=dict(mandatory=True, ),
        beta=dict(
            extensions=None,
            mandatory=True,
        ),
        constants=dict(mandatory=True, ),
        contrasts=dict(mandatory=True, ),
        dof=dict(mandatory=True, ),
        mask=dict(extensions=None, ),
        nvbeta=dict(mandatory=True, ),
        reg_names=dict(mandatory=True, ),
        s2=dict(
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = EstimateContrast.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_EstimateContrast_outputs():
    output_map = dict(
        p_maps=dict(),
        stat_maps=dict(),
        z_maps=dict(),
    )
    outputs = EstimateContrast.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..io import S3DataGrabber


def test_S3DataGrabber_inputs():
    input_map = dict(
        anon=dict(usedefault=True, ),
        bucket=dict(mandatory=True, ),
        bucket_path=dict(usedefault=True, ),
        local_directory=dict(),
        raise_on_empty=dict(usedefault=True, ),
        region=dict(usedefault=True, ),
        sort_filelist=dict(mandatory=True, ),
        template=dict(mandatory=True, ),
        template_args=dict(),
    )
    inputs = S3DataGrabber.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_S3DataGrabber_outputs():
    output_map = dict()
    outputs = S3DataGrabber.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..cmtk import CreateNodes


def test_CreateNodes_inputs():
    input_map = dict(
        out_filename=dict(
            extensions=None,
            usedefault=True,
        ),
        resolution_network_file=dict(
            extensions=None,
            mandatory=True,
        ),
        roi_file=dict(
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = CreateNodes.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_CreateNodes_outputs():
    output_map = dict(node_network=dict(extensions=None, ), )
    outputs = CreateNodes.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..nx import NetworkXMetrics


def test_NetworkXMetrics_inputs():
    input_map = dict(
        compute_clique_related_measures=dict(usedefault=True, ),
        in_file=dict(
            extensions=None,
            mandatory=True,
        ),
        out_edge_metrics_matlab=dict(
            extensions=None,
            genfile=True,
        ),
        out_global_metrics_matlab=dict(
            extensions=None,
            genfile=True,
        ),
        out_k_core=dict(
            extensions=None,
            usedefault=True,
        ),
        out_k_crust=dict(
            extensions=None,
            usedefault=True,
        ),
        out_k_shell=dict(
            extensions=None,
            usedefault=True,
        ),
        out_node_metrics_matlab=dict(
            extensions=None,
            genfile=True,
        ),
        out_pickled_extra_measures=dict(
            extensions=None,
            usedefault=True,
        ),
        treat_as_weighted_graph=dict(usedefault=True, ),
    )
    inputs = NetworkXMetrics.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_NetworkXMetrics_outputs():
    output_map = dict(
        edge_measure_networks=dict(),
        edge_measures_matlab=dict(extensions=None, ),
        global_measures_matlab=dict(extensions=None, ),
        gpickled_network_files=dict(),
        k_core=dict(extensions=None, ),
        k_crust=dict(extensions=None, ),
        k_networks=dict(),
        k_shell=dict(extensions=None, ),
        matlab_dict_measures=dict(),
        matlab_matrix_files=dict(),
        node_measure_networks=dict(),
        node_measures_matlab=dict(extensions=None, ),
        pickled_extra_measures=dict(extensions=None, ),
    )
    outputs = NetworkXMetrics.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..io import SelectFiles


def test_SelectFiles_inputs():
    input_map = dict(
        base_directory=dict(),
        force_lists=dict(usedefault=True, ),
        raise_on_empty=dict(usedefault=True, ),
        sort_filelist=dict(usedefault=True, ),
    )
    inputs = SelectFiles.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SelectFiles_outputs():
    output_map = dict()
    outputs = SelectFiles.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..featuredetection import HammerAttributeCreator


def test_HammerAttributeCreator_inputs():
    input_map = dict(
        Scale=dict(argstr='--Scale %d', ),
        Strength=dict(argstr='--Strength %f', ),
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputCSFVolume=dict(
            argstr='--inputCSFVolume %s',
            extensions=None,
        ),
        inputGMVolume=dict(
            argstr='--inputGMVolume %s',
            extensions=None,
        ),
        inputWMVolume=dict(
            argstr='--inputWMVolume %s',
            extensions=None,
        ),
        outputVolumeBase=dict(argstr='--outputVolumeBase %s', ),
    )
    inputs = HammerAttributeCreator.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_HammerAttributeCreator_outputs():
    output_map = dict()
    outputs = HammerAttributeCreator.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..misc import Matlab2CSV


def test_Matlab2CSV_inputs():
    input_map = dict(
        in_file=dict(
            extensions=None,
            mandatory=True,
        ),
        reshape_matrix=dict(usedefault=True, ),
    )
    inputs = Matlab2CSV.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Matlab2CSV_outputs():
    output_map = dict(csv_files=dict(), )
    outputs = Matlab2CSV.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..model import EstimateContrast


def test_EstimateContrast_inputs():
    input_map = dict(
        beta_images=dict(
            copyfile=False,
            mandatory=True,
        ),
        contrasts=dict(mandatory=True, ),
        group_contrast=dict(xor=['use_derivs'], ),
        matlab_cmd=dict(),
        mfile=dict(usedefault=True, ),
        paths=dict(),
        residual_image=dict(
            copyfile=False,
            extensions=None,
            mandatory=True,
        ),
        spm_mat_file=dict(
            copyfile=True,
            extensions=None,
            field='spmmat',
            mandatory=True,
        ),
        use_derivs=dict(xor=['group_contrast'], ),
        use_mcr=dict(),
        use_v8struct=dict(
            min_ver='8',
            usedefault=True,
        ),
    )
    inputs = EstimateContrast.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_EstimateContrast_outputs():
    output_map = dict(
        con_images=dict(),
        ess_images=dict(),
        spmF_images=dict(),
        spmT_images=dict(),
        spm_mat_file=dict(extensions=None, ),
    )
    outputs = EstimateContrast.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import MRConvert


def test_MRConvert_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        extension=dict(
            position=2,
            usedefault=True,
        ),
        extract_at_axis=dict(
            argstr='-coord %s',
            position=1,
        ),
        extract_at_coordinate=dict(
            argstr='%s',
            position=2,
            sep=',',
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        layout=dict(
            argstr='-output %s',
            position=2,
        ),
        offset_bias=dict(
            argstr='-scale %d',
            position=3,
            units='mm',
        ),
        out_filename=dict(
            argstr='%s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        output_datatype=dict(
            argstr='-output %s',
            position=2,
        ),
        prs=dict(
            argstr='-prs',
            position=3,
        ),
        replace_NaN_with_zero=dict(
            argstr='-zero',
            position=3,
        ),
        resample=dict(
            argstr='-scale %d',
            position=3,
            units='mm',
        ),
        voxel_dims=dict(
            argstr='-vox %s',
            position=3,
            sep=',',
        ),
    )
    inputs = MRConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MRConvert_outputs():
    output_map = dict(converted=dict(extensions=None, ), )
    outputs = MRConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..gtract import gtractCoregBvalues


def test_gtractCoregBvalues_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        debugLevel=dict(argstr='--debugLevel %d', ),
        eddyCurrentCorrection=dict(argstr='--eddyCurrentCorrection ', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        fixedVolume=dict(
            argstr='--fixedVolume %s',
            extensions=None,
        ),
        fixedVolumeIndex=dict(argstr='--fixedVolumeIndex %d', ),
        maximumStepSize=dict(argstr='--maximumStepSize %f', ),
        minimumStepSize=dict(argstr='--minimumStepSize %f', ),
        movingVolume=dict(
            argstr='--movingVolume %s',
            extensions=None,
        ),
        numberOfIterations=dict(argstr='--numberOfIterations %d', ),
        numberOfSpatialSamples=dict(argstr='--numberOfSpatialSamples %d', ),
        numberOfThreads=dict(argstr='--numberOfThreads %d', ),
        outputTransform=dict(
            argstr='--outputTransform %s',
            hash_files=False,
        ),
        outputVolume=dict(
            argstr='--outputVolume %s',
            hash_files=False,
        ),
        registerB0Only=dict(argstr='--registerB0Only ', ),
        relaxationFactor=dict(argstr='--relaxationFactor %f', ),
        samplingPercentage=dict(argstr='--samplingPercentage %f', ),
        spatialScale=dict(argstr='--spatialScale %f', ),
    )
    inputs = gtractCoregBvalues.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_gtractCoregBvalues_outputs():
    output_map = dict(
        outputTransform=dict(extensions=None, ),
        outputVolume=dict(extensions=None, ),
    )
    outputs = gtractCoregBvalues.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""This commandline module provides classes for interfacing with the
`ICA-AROMA.py<https://github.com/rhr-pruim/ICA-AROMA>`_ command line tool.
"""

from __future__ import (print_function, division, unicode_literals,
                        absolute_import)
from ..base import (TraitedSpec, CommandLineInputSpec, CommandLine, File,
                    Directory, traits, isdefined)
import os


class ICA_AROMAInputSpec(CommandLineInputSpec):
    feat_dir = Directory(
        exists=True,
        mandatory=True,
        argstr='-feat %s',
        xor=['in_file', 'mat_file', 'fnirt_warp_file', 'motion_parameters'],
        desc='If a feat directory exists and temporal filtering '
        'has not been run yet, ICA_AROMA can use the files in '
        'this directory.')
    in_file = File(
        exists=True,
        mandatory=True,
        argstr='-i %s',
        xor=['feat_dir'],
        desc='volume to be denoised')
    out_dir = Directory(
        'out', usedefault=True, mandatory=True,
        argstr='-o %s', desc='output directory')
    mask = File(
        exists=True,
        argstr='-m %s',
        xor=['feat_dir'],
        desc='path/name volume mask')
    dim = traits.Int(
        argstr='-dim %d',
        desc='Dimensionality reduction when running '
        'MELODIC (defualt is automatic estimation)')
    TR = traits.Float(
        argstr='-tr %.3f',
        desc='TR in seconds. If this is not specified '
        'the TR will be extracted from the '
        'header of the fMRI nifti file.')
    melodic_dir = Directory(
        exists=True,
        argstr='-meldir %s',
        desc='path to MELODIC directory if MELODIC has already been run')
    mat_file = File(
        exists=True,
        argstr='-affmat %s',
        xor=['feat_dir'],
        desc='path/name of the mat-file describing the '
        'affine registration (e.g. FSL FLIRT) of the '
        'functional data to structural space (.mat file)')
    fnirt_warp_file = File(
        exists=True,
        argstr='-warp %s',
        xor=['feat_dir'],
        desc='File name of the warp-file describing '
        'the non-linear registration (e.g. FSL FNIRT) '
        'of the structural data to MNI152 space (.nii.gz)')
    motion_parameters = File(
        exists=True,
        mandatory=True,
        argstr='-mc %s',
        xor=['feat_dir'],
        desc='motion parameters file')
    denoise_type = traits.Enum(
        'nonaggr',
        'aggr',
        'both',
        'no',
        usedefault=True,
        mandatory=True,
        argstr='-den %s',
        desc='Type of denoising strategy:\n'
        '-no: only classification, no denoising\n'
        '-nonaggr (default): non-aggresssive denoising, i.e. partial component regression\n'
        '-aggr: aggressive denoising, i.e. full component regression\n'
        '-both: both aggressive and non-aggressive denoising (two outputs)')


class ICA_AROMAOutputSpec(TraitedSpec):
    aggr_denoised_file = File(
        exists=True, desc='if generated: aggressively denoised volume')
    nonaggr_denoised_file = File(
        exists=True, desc='if generated: non aggressively denoised volume')
    out_dir = Directory(
        exists=True,
        desc='directory contains (in addition to the denoised files): '
        'melodic.ica + classified_motion_components + '
        'classification_overview + feature_scores + melodic_ic_mni)')


class ICA_AROMA(CommandLine):
    """
    Interface for the ICA_AROMA.py script.

    ICA-AROMA (i.e. 'ICA-based Automatic Removal Of Motion Artifacts') concerns
    a data-driven method to identify and remove motion-related independent
    components from fMRI data. To that end it exploits a small, but robust
    set of theoretically motivated features, preventing the need for classifier
    re-training and therefore providing direct and easy applicability.

    See link for further documentation: https://github.com/rhr-pruim/ICA-AROMA

    Example
    -------

    >>> from nipype.interfaces.fsl import ICA_AROMA
    >>> from nipype.testing import example_data
    >>> AROMA_obj = ICA_AROMA()
    >>> AROMA_obj.inputs.in_file = 'functional.nii'
    >>> AROMA_obj.inputs.mat_file = 'func_to_struct.mat'
    >>> AROMA_obj.inputs.fnirt_warp_file = 'warpfield.nii'
    >>> AROMA_obj.inputs.motion_parameters = 'fsl_mcflirt_movpar.txt'
    >>> AROMA_obj.inputs.mask = 'mask.nii.gz'
    >>> AROMA_obj.inputs.denoise_type = 'both'
    >>> AROMA_obj.inputs.out_dir = 'ICA_testout'
    >>> AROMA_obj.cmdline  # doctest: +ELLIPSIS
    'ICA_AROMA.py -den both -warp warpfield.nii -i functional.nii -m mask.nii.gz -affmat func_to_struct.mat -mc fsl_mcflirt_movpar.txt -o .../ICA_testout'
    """
    _cmd = 'ICA_AROMA.py'
    input_spec = ICA_AROMAInputSpec
    output_spec = ICA_AROMAOutputSpec

    def _format_arg(self, name, trait_spec, value):
        if name == 'out_dir':
            return trait_spec.argstr % os.path.abspath(value)
        return super(ICA_AROMA, self)._format_arg(name, trait_spec, value)

    def _list_outputs(self):
        outputs = self.output_spec().get()
        outputs['out_dir'] = os.path.abspath(self.inputs.out_dir)
        out_dir = outputs['out_dir']

        if self.inputs.denoise_type in ('aggr', 'both'):
            outputs['aggr_denoised_file'] = os.path.join(
                out_dir, 'denoised_func_data_aggr.nii.gz')
        if self.inputs.denoise_type in ('nonaggr', 'both'):
            outputs['nonaggr_denoised_file'] = os.path.join(
                out_dir, 'denoised_func_data_nonaggr.nii.gz')
        return outputs



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..odf import SFPeaks


def test_SFPeaks_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        density=dict(
            argstr='-density %d',
            units='NA',
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='-inputfile %s',
            extensions=None,
            mandatory=True,
        ),
        inputmodel=dict(
            argstr='-inputmodel %s',
            mandatory=True,
        ),
        mepointset=dict(
            argstr='-mepointset %d',
            units='NA',
        ),
        noconsistencycheck=dict(argstr='-noconsistencycheck', ),
        numpds=dict(
            argstr='-numpds %d',
            units='NA',
        ),
        order=dict(
            argstr='-order %d',
            units='NA',
        ),
        out_file=dict(
            argstr='> %s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        pdthresh=dict(
            argstr='-pdthresh %f',
            units='NA',
        ),
        pointset=dict(
            argstr='-pointset %d',
            units='NA',
        ),
        rbfpointset=dict(
            argstr='-rbfpointset %d',
            units='NA',
        ),
        scheme_file=dict(
            argstr='%s',
            extensions=None,
        ),
        searchradius=dict(
            argstr='-searchradius %f',
            units='NA',
        ),
        stdsfrommean=dict(
            argstr='-stdsfrommean %f',
            units='NA',
        ),
    )
    inputs = SFPeaks.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SFPeaks_outputs():
    output_map = dict(peaks=dict(extensions=None, ), )
    outputs = SFPeaks.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..odf import HARDIMat


def test_HARDIMat_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        bvals=dict(
            extensions=None,
            mandatory=True,
        ),
        bvecs=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        image_info=dict(
            argstr='-info %s',
            extensions=None,
        ),
        image_orientation_vectors=dict(argstr='-iop %f', ),
        oblique_correction=dict(argstr='-oc', ),
        odf_file=dict(
            argstr='-odf %s',
            extensions=None,
        ),
        order=dict(argstr='-order %s', ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            position=2,
            usedefault=True,
        ),
        reference_file=dict(
            argstr='-ref %s',
            extensions=None,
        ),
    )
    inputs = HARDIMat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_HARDIMat_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = HARDIMat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""Top-level namespace for freesurfer."""

from .base import Info, FSCommand, no_freesurfer
from .preprocess import (
    ParseDICOMDir, UnpackSDICOMDir, MRIConvert, Resample, ReconAll, BBRegister,
    ApplyVolTransform, Smooth, DICOMConvert, RobustRegister, FitMSParams,
    SynthesizeFLASH, MNIBiasCorrection, WatershedSkullStrip, Normalize,
    CANormalize, CARegister, CALabel, MRIsCALabel, SegmentCC, SegmentWM,
    EditWMwithAseg, ConcatenateLTA)
from .model import (MRISPreproc, MRISPreprocReconAll, GLMFit, OneSampleTTest,
                    Binarize, Concatenate, SegStats, SegStatsReconAll,
                    Label2Vol, MS_LDA, Label2Label, Label2Annot,
                    SphericalAverage)
from .utils import (
    SampleToSurface, SurfaceSmooth, SurfaceTransform, Surface2VolTransform,
    SurfaceSnapshots, ApplyMask, MRIsConvert, MRITessellate, MRIPretess,
    MRIMarchingCubes, SmoothTessellation, MakeAverageSubject,
    ExtractMainComponent, Tkregister2, AddXFormToHeader,
    CheckTalairachAlignment, TalairachAVI, TalairachQC, RemoveNeck, MRIFill,
    MRIsInflate, Sphere, FixTopology, EulerNumber, RemoveIntersection,
    MakeSurfaces, Curvature, CurvatureStats, Jacobian, MRIsCalc, VolumeMask,
    ParcellationStats, Contrast, RelabelHypointensities, Aparc2Aseg, Apas2Aseg,
    MRIsExpand, MRIsCombine)
from .longitudinal import (RobustTemplate, FuseSegmentations)
from .registration import (MPRtoMNI305, RegisterAVItoTalairach, EMRegister,
                           Register, Paint, MRICoreg)



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..developer import MedicAlgorithmLesionToads


def test_MedicAlgorithmLesionToads_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inAtlas=dict(argstr='--inAtlas %s', ),
        inAtlas2=dict(
            argstr='--inAtlas2 %s',
            extensions=None,
        ),
        inAtlas3=dict(
            argstr='--inAtlas3 %s',
            extensions=None,
        ),
        inAtlas4=dict(
            argstr='--inAtlas4 %s',
            extensions=None,
        ),
        inAtlas5=dict(argstr='--inAtlas5 %f', ),
        inAtlas6=dict(argstr='--inAtlas6 %s', ),
        inConnectivity=dict(argstr='--inConnectivity %s', ),
        inCorrect=dict(argstr='--inCorrect %s', ),
        inFLAIR=dict(
            argstr='--inFLAIR %s',
            extensions=None,
        ),
        inInclude=dict(argstr='--inInclude %s', ),
        inMaximum=dict(argstr='--inMaximum %d', ),
        inMaximum2=dict(argstr='--inMaximum2 %d', ),
        inMaximum3=dict(argstr='--inMaximum3 %d', ),
        inMaximum4=dict(argstr='--inMaximum4 %f', ),
        inMaximum5=dict(argstr='--inMaximum5 %d', ),
        inOutput=dict(argstr='--inOutput %s', ),
        inOutput2=dict(argstr='--inOutput2 %s', ),
        inOutput3=dict(argstr='--inOutput3 %s', ),
        inSmooting=dict(argstr='--inSmooting %f', ),
        inT1_MPRAGE=dict(
            argstr='--inT1_MPRAGE %s',
            extensions=None,
        ),
        inT1_SPGR=dict(
            argstr='--inT1_SPGR %s',
            extensions=None,
        ),
        null=dict(argstr='--null %s', ),
        outCortical=dict(
            argstr='--outCortical %s',
            hash_files=False,
        ),
        outFilled=dict(
            argstr='--outFilled %s',
            hash_files=False,
        ),
        outHard=dict(
            argstr='--outHard %s',
            hash_files=False,
        ),
        outHard2=dict(
            argstr='--outHard2 %s',
            hash_files=False,
        ),
        outInhomogeneity=dict(
            argstr='--outInhomogeneity %s',
            hash_files=False,
        ),
        outLesion=dict(
            argstr='--outLesion %s',
            hash_files=False,
        ),
        outMembership=dict(
            argstr='--outMembership %s',
            hash_files=False,
        ),
        outSulcal=dict(
            argstr='--outSulcal %s',
            hash_files=False,
        ),
        outWM=dict(
            argstr='--outWM %s',
            hash_files=False,
        ),
        xDefaultMem=dict(argstr='-xDefaultMem %d', ),
        xMaxProcess=dict(
            argstr='-xMaxProcess %d',
            usedefault=True,
        ),
        xPrefExt=dict(argstr='--xPrefExt %s', ),
    )
    inputs = MedicAlgorithmLesionToads.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MedicAlgorithmLesionToads_outputs():
    output_map = dict(
        outCortical=dict(extensions=None, ),
        outFilled=dict(extensions=None, ),
        outHard=dict(extensions=None, ),
        outHard2=dict(extensions=None, ),
        outInhomogeneity=dict(extensions=None, ),
        outLesion=dict(extensions=None, ),
        outMembership=dict(extensions=None, ),
        outSulcal=dict(extensions=None, ),
        outWM=dict(extensions=None, ),
    )
    outputs = MedicAlgorithmLesionToads.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..io import DataSink


def test_DataSink_inputs():
    input_map = dict(
        _outputs=dict(usedefault=True, ),
        base_directory=dict(),
        bucket=dict(),
        container=dict(),
        creds_path=dict(),
        encrypt_bucket_keys=dict(),
        local_copy=dict(),
        parameterization=dict(usedefault=True, ),
        regexp_substitutions=dict(),
        remove_dest_dir=dict(usedefault=True, ),
        strip_dir=dict(),
        substitutions=dict(),
    )
    inputs = DataSink.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_DataSink_outputs():
    output_map = dict(out_file=dict(), )
    outputs = DataSink.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



from __future__ import absolute_import
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
# -*- coding: utf-8 -*-

from .utils import (Mesh2PVE, Generate5tt, BrainMask, TensorMetrics,
                    ComputeTDI, TCK2VTK, MRMath, MRConvert, MRResize,
                    DWIExtract)
from .preprocess import (ResponseSD, ACTPrepareFSL, ReplaceFSwithFIRST,
                         DWIDenoise, MRDeGibbs, DWIBiasCorrect)
from .tracking import Tractography
from .reconst import FitTensor, EstimateFOD
from .connectivity import LabelConfig, LabelConvert, BuildConnectome



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..qt1 import FitQt1


def test_FitQt1_inputs():
    input_map = dict(
        acceptance=dict(argstr='-acceptance %f', ),
        args=dict(argstr='%s', ),
        b1map=dict(
            argstr='-b1map %s',
            extensions=None,
        ),
        comp_file=dict(
            argstr='-comp %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_comp.nii.gz',
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        error_file=dict(
            argstr='-error %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_error.nii.gz',
        ),
        flips=dict(
            argstr='-flips %s',
            sep=' ',
        ),
        flips_list=dict(
            argstr='-fliplist %s',
            extensions=None,
        ),
        gn_flag=dict(
            argstr='-gn',
            position=8,
        ),
        ir_flag=dict(
            argstr='-IR',
            position=13,
        ),
        lm_val=dict(
            argstr='-lm %f %f',
            position=7,
        ),
        m0map_file=dict(
            argstr='-m0map %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_m0map.nii.gz',
        ),
        mask=dict(
            argstr='-mask %s',
            extensions=None,
            position=2,
        ),
        maxit=dict(
            argstr='-maxit %d',
            position=11,
        ),
        mcmap_file=dict(
            argstr='-mcmap %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_mcmap.nii.gz',
        ),
        mcmaxit=dict(argstr='-mcmaxit %d', ),
        mcout=dict(
            argstr='-mcout %s',
            extensions=None,
        ),
        mcsamples=dict(argstr='-mcsamples %d', ),
        nb_comp=dict(
            argstr='-nc %d',
            position=6,
        ),
        prior=dict(
            argstr='-prior %s',
            extensions=None,
            position=3,
        ),
        res_file=dict(
            argstr='-res %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_res.nii.gz',
        ),
        slice_no=dict(
            argstr='-slice %d',
            position=9,
        ),
        source_file=dict(
            argstr='-source %s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        spgr=dict(argstr='-SPGR', ),
        sr_flag=dict(
            argstr='-SR',
            position=12,
        ),
        syn_file=dict(
            argstr='-syn %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_syn.nii.gz',
        ),
        t1_list=dict(
            argstr='-T1list %s',
            extensions=None,
        ),
        t1map_file=dict(
            argstr='-t1map %s',
            extensions=None,
            name_source=['source_file'],
            name_template='%s_t1map.nii.gz',
        ),
        t1max=dict(argstr='-T1max %f', ),
        t1min=dict(argstr='-T1min %f', ),
        te_value=dict(
            argstr='-TE %f',
            position=4,
        ),
        tis=dict(
            argstr='-TIs %s',
            position=14,
            sep=' ',
        ),
        tis_list=dict(
            argstr='-TIlist %s',
            extensions=None,
        ),
        tr_value=dict(
            argstr='-TR %f',
            position=5,
        ),
        voxel=dict(
            argstr='-voxel %d %d %d',
            position=10,
        ),
    )
    inputs = FitQt1.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_FitQt1_outputs():
    output_map = dict(
        comp_file=dict(extensions=None, ),
        error_file=dict(extensions=None, ),
        m0map_file=dict(extensions=None, ),
        mcmap_file=dict(extensions=None, ),
        res_file=dict(extensions=None, ),
        syn_file=dict(extensions=None, ),
        t1map_file=dict(extensions=None, ),
    )
    outputs = FitQt1.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import Volreg


def test_Volreg_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        basefile=dict(
            argstr='-base %s',
            extensions=None,
            position=-6,
        ),
        copyorigin=dict(argstr='-twodup', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        in_weight_volume=dict(argstr="-weight '%s[%d]'", ),
        interp=dict(argstr='-%s', ),
        md1d_file=dict(
            argstr='-maxdisp1D %s',
            extensions=None,
            keep_extension=True,
            name_source='in_file',
            name_template='%s_md.1D',
            position=-4,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        oned_file=dict(
            argstr='-1Dfile %s',
            extensions=None,
            keep_extension=True,
            name_source='in_file',
            name_template='%s.1D',
        ),
        oned_matrix_save=dict(
            argstr='-1Dmatrix_save %s',
            extensions=None,
            keep_extension=True,
            name_source='in_file',
            name_template='%s.aff12.1D',
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_file',
            name_template='%s_volreg',
        ),
        outputtype=dict(),
        timeshift=dict(argstr='-tshift 0', ),
        verbose=dict(argstr='-verbose', ),
        zpad=dict(
            argstr='-zpad %d',
            position=-5,
        ),
    )
    inputs = Volreg.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Volreg_outputs():
    output_map = dict(
        md1d_file=dict(extensions=None, ),
        oned_file=dict(extensions=None, ),
        oned_matrix_save=dict(extensions=None, ),
        out_file=dict(extensions=None, ),
    )
    outputs = Volreg.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import MaskTool


def test_MaskTool_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        count=dict(
            argstr='-count',
            position=2,
        ),
        datum=dict(argstr='-datum %s', ),
        dilate_inputs=dict(argstr='-dilate_inputs %s', ),
        dilate_results=dict(argstr='-dilate_results %s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        fill_dirs=dict(
            argstr='-fill_dirs %s',
            requires=['fill_holes'],
        ),
        fill_holes=dict(argstr='-fill_holes', ),
        frac=dict(argstr='-frac %s', ),
        in_file=dict(
            argstr='-input %s',
            copyfile=False,
            mandatory=True,
            position=-1,
        ),
        inter=dict(argstr='-inter', ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_file',
            name_template='%s_mask',
        ),
        outputtype=dict(),
        union=dict(argstr='-union', ),
        verbose=dict(argstr='-verb %s', ),
    )
    inputs = MaskTool.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MaskTool_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = MaskTool.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..specialized import FiducialRegistration


def test_FiducialRegistration_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        fixedLandmarks=dict(argstr='--fixedLandmarks %s...', ),
        movingLandmarks=dict(argstr='--movingLandmarks %s...', ),
        outputMessage=dict(argstr='--outputMessage %s', ),
        rms=dict(argstr='--rms %f', ),
        saveTransform=dict(
            argstr='--saveTransform %s',
            hash_files=False,
        ),
        transformType=dict(argstr='--transformType %s', ),
    )
    inputs = FiducialRegistration.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_FiducialRegistration_outputs():
    output_map = dict(saveTransform=dict(extensions=None, ), )
    outputs = FiducialRegistration.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..model import MultipleRegressDesign


def test_MultipleRegressDesign_inputs():
    input_map = dict(
        contrasts=dict(mandatory=True, ),
        groups=dict(),
        regressors=dict(mandatory=True, ),
    )
    inputs = MultipleRegressDesign.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MultipleRegressDesign_outputs():
    output_map = dict(
        design_con=dict(extensions=None, ),
        design_fts=dict(extensions=None, ),
        design_grp=dict(extensions=None, ),
        design_mat=dict(extensions=None, ),
    )
    outputs = MultipleRegressDesign.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""DTITK utility interfaces

DTI-TK developed by Gary Hui Zhang, gary.zhang@ucl.ac.uk
For additional help, visit http://dti-tk.sf.net

The high-dimensional tensor-based DTI registration algorithm

Zhang, H., Avants, B.B, Yushkevich, P.A., Woo, J.H., Wang, S., McCluskey, L.H.,
Elman, L.B., Melhem, E.R., Gee, J.C., High-dimensional spatial normalization of
diffusion tensor images improves the detection of white matter differences in
amyotrophic lateral sclerosis, IEEE Transactions on Medical Imaging,
26(11):1585-1597, November 2007. PMID: 18041273.

The original piecewise-affine tensor-based DTI registration algorithm at the
core of DTI-TK

Zhang, H., Yushkevich, P.A., Alexander, D.C., Gee, J.C., Deformable
registration of diffusion tensor MR images with explicit orientation
optimization, Medical Image Analysis, 10(5):764-785, October 2006. PMID:
16899392.

"""

from ..base import TraitedSpec, CommandLineInputSpec, File, traits, isdefined
from ...utils.filemanip import fname_presuffix
from .base import CommandLineDtitk, DTITKRenameMixin
import os

__docformat__ = 'restructuredtext'


class TVAdjustVoxSpInputSpec(CommandLineInputSpec):
    in_file = File(desc="tensor volume to modify", exists=True,
                   mandatory=True, argstr="-in %s")
    out_file = File(desc='output path',
                    argstr="-out %s", name_source='in_file',
                    name_template='%s_avs', keep_extension=True)
    target_file = File(desc='target volume to match',
                       argstr="-target %s",
                       xor=['voxel_size', 'origin'])
    voxel_size = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                              desc='xyz voxel size (superseded by target)',
                              argstr="-vsize %g %g %g", xor=['target_file'])
    origin = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                          desc='xyz origin (superseded by target)',
                          argstr='-origin %g %g %g',
                          xor=['target_file'])


class TVAdjustVoxSpOutputSpec(TraitedSpec):
    out_file = File(exists=True)


class TVAdjustVoxSp(CommandLineDtitk):
    """
     Adjusts the voxel space of a tensor volume

    Example
    -------

    >>> from nipype.interfaces import dtitk
    >>> node = dtitk.TVAdjustVoxSp()
    >>> node.inputs.in_file = 'im1.nii'
    >>> node.inputs.target_file = 'im2.nii'
    >>> node.cmdline
    'TVAdjustVoxelspace -in im1.nii -out im1_avs.nii -target im2.nii'
    >>> node.run() # doctest: +SKIP
    """
    input_spec = TVAdjustVoxSpInputSpec
    output_spec = TVAdjustVoxSpOutputSpec
    _cmd = 'TVAdjustVoxelspace'


class SVAdjustVoxSpInputSpec(CommandLineInputSpec):
    in_file = File(desc="scalar volume to modify", exists=True,
                   mandatory=True, argstr="-in %s")
    out_file = File(desc='output path', argstr="-out %s",
                    name_source="in_file", name_template='%s_avs',
                    keep_extension=True)
    target_file = File(desc='target volume to match',
                       argstr="-target %s", xor=['voxel_size', 'origin'])
    voxel_size = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                              desc='xyz voxel size (superseded by target)',
                              argstr="-vsize %g %g %g", xor=['target_file'])
    origin = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                          desc='xyz origin (superseded by target)',
                          argstr='-origin %g %g %g',
                          xor=['target_file'])


class SVAdjustVoxSpOutputSpec(TraitedSpec):
    out_file = File(exists=True)


class SVAdjustVoxSp(CommandLineDtitk):
    """
     Adjusts the voxel space of a scalar volume

        Example
        -------

        >>> from nipype.interfaces import dtitk
        >>> node = dtitk.SVAdjustVoxSp()
        >>> node.inputs.in_file = 'im1.nii'
        >>> node.inputs.target_file = 'im2.nii'
        >>> node.cmdline
        'SVAdjustVoxelspace -in im1.nii -out im1_avs.nii -target im2.nii'
        >>> node.run() # doctest: +SKIP
        """
    input_spec = SVAdjustVoxSpInputSpec
    output_spec = SVAdjustVoxSpOutputSpec
    _cmd = 'SVAdjustVoxelspace'


class TVResampleInputSpec(CommandLineInputSpec):
    in_file = File(desc="tensor volume to resample", exists=True,
                   mandatory=True, argstr="-in %s")
    out_file = File(desc='output path',
                    name_source="in_file", name_template="%s_resampled",
                    keep_extension=True, argstr="-out %s")
    target_file = File(desc='specs read from the target volume',
                       argstr="-target %s",
                       xor=['array_size', 'voxel_size', 'origin'])
    align = traits.Enum('center', 'origin', argstr="-align %s",
                        desc='how to align output volume to input volume')
    interpolation = traits.Enum('LEI', 'EI', argstr="-interp %s",
                                desc='Log Euclidean Euclidean Interpolation')
    array_size = traits.Tuple((traits.Int(), traits.Int(), traits.Int()),
                              desc='resampled array size', xor=['target_file'],
                              argstr="-size %d %d %d")
    voxel_size = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                              desc='resampled voxel size', xor=['target_file'],
                              argstr="-vsize %g %g %g")
    origin = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                          desc='xyz origin', xor=['target_file'],
                          argstr='-origin %g %g %g')


class TVResampleOutputSpec(TraitedSpec):
    out_file = File(exists=True)


class TVResample(CommandLineDtitk):
    """
    Resamples a tensor volume

        Example
        -------

        >>> from nipype.interfaces import dtitk
        >>> node = dtitk.TVResample()
        >>> node.inputs.in_file = 'im1.nii'
        >>> node.inputs.target_file = 'im2.nii'
        >>> node.cmdline
        'TVResample -in im1.nii -out im1_resampled.nii -target im2.nii'
        >>> node.run() # doctest: +SKIP
        """
    input_spec = TVResampleInputSpec
    output_spec = TVResampleOutputSpec
    _cmd = 'TVResample'


class SVResampleInputSpec(CommandLineInputSpec):
    in_file = File(desc="image to resample", exists=True,
                   mandatory=True, argstr="-in %s")
    out_file = File(desc='output path',
                    name_source="in_file", name_template="%s_resampled",
                    keep_extension=True, argstr="-out %s")
    target_file = File(desc='specs read from the target volume',
                       argstr="-target %s",
                       xor=['array_size', 'voxel_size', 'origin'])
    align = traits.Enum('center', 'origin', argstr="-align %s",
                        desc='how to align output volume to input volume')
    array_size = traits.Tuple((traits.Int(), traits.Int(), traits.Int()),
                              desc='resampled array size', xor=['target_file'],
                              argstr="-size %d %d %d")
    voxel_size = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                              desc='resampled voxel size', xor=['target_file'],
                              argstr="-vsize %g %g %g")
    origin = traits.Tuple((traits.Float(), traits.Float(), traits.Float()),
                          desc='xyz origin', xor=['target_file'],
                          argstr='-origin %g %g %g')


class SVResampleOutputSpec(TraitedSpec):
    out_file = File(exists=True)


class SVResample(CommandLineDtitk):
    """
    Resamples a scalar volume

        Example
        -------

        >>> from nipype.interfaces import dtitk
        >>> node = dtitk.SVResample()
        >>> node.inputs.in_file = 'im1.nii'
        >>> node.inputs.target_file = 'im2.nii'
        >>> node.cmdline
        'SVResample -in im1.nii -out im1_resampled.nii -target im2.nii'
        >>> node.run() # doctest: +SKIP
        """
    input_spec = SVResampleInputSpec
    output_spec = SVResampleOutputSpec
    _cmd = 'SVResample'


class TVtoolInputSpec(CommandLineInputSpec):
    in_file = File(desc="scalar volume to resample", exists=True,
                   argstr="-in %s", mandatory=True)
    '''NOTE: there are a lot more options here; not implementing all of them'''
    in_flag = traits.Enum('fa', 'tr', 'ad', 'rd', 'pd', 'rgb',
                          argstr="-%s", desc='')
    out_file = File(argstr="-out %s", genfile=True)


class TVtoolOutputSpec(TraitedSpec):
    out_file = File()


class TVtool(CommandLineDtitk):
    """
    Calculates a tensor metric volume from a tensor volume

        Example
        -------

        >>> from nipype.interfaces import dtitk
        >>> node = dtitk.TVtool()
        >>> node.inputs.in_file = 'im1.nii'
        >>> node.inputs.in_flag = 'fa'
        >>> node.cmdline
        'TVtool -in im1.nii -fa -out im1_fa.nii'
        >>> node.run() # doctest: +SKIP
        """
    input_spec = TVtoolInputSpec
    output_spec = TVtoolOutputSpec
    _cmd = 'TVtool'

    def _list_outputs(self):
        outputs = self._outputs().get()
        out_file = self.inputs.out_file
        if not isdefined(out_file):
            out_file = self._gen_filename('out_file')
        outputs['out_file'] = os.path.abspath(out_file)
        return outputs

    def _gen_filename(self, name):
        if name != 'out_file':
            return
        return fname_presuffix(os.path.basename(self.inputs.in_file),
                               suffix='_' + self.inputs.in_flag)


'''Note: SVTool not implemented at this time'''


class BinThreshInputSpec(CommandLineInputSpec):
    in_file = File(desc='Image to threshold/binarize', exists=True,
                   position=0, argstr="%s", mandatory=True)
    out_file = File(desc='output path',  position=1, argstr="%s",
                    keep_extension=True, name_source='in_file',
                    name_template='%s_thrbin')
    lower_bound = traits.Float(0.01, usedefault=True,
                               position=2, argstr="%g", mandatory=True,
                               desc='lower bound of binarization range')
    upper_bound = traits.Float(100, usedefault=True,
                               position=3, argstr="%g", mandatory=True,
                               desc='upper bound of binarization range')
    inside_value = traits.Float(1, position=4, argstr="%g", usedefault=True,
                                mandatory=True, desc='value for voxels in '
                                'binarization range')
    outside_value = traits.Float(0, position=5, argstr="%g", usedefault=True,
                                 mandatory=True, desc='value for voxels'
                                 'outside of binarization range')


class BinThreshOutputSpec(TraitedSpec):
    out_file = File(exists=True)


class BinThresh(CommandLineDtitk):
    """
    Binarizes an image

    Example
    -------

    >>> from nipype.interfaces import dtitk
    >>> node = dtitk.BinThresh()
    >>> node.inputs.in_file = 'im1.nii'
    >>> node.inputs.lower_bound = 0
    >>> node.inputs.upper_bound = 100
    >>> node.inputs.inside_value = 1
    >>> node.inputs.outside_value = 0
    >>> node.cmdline
    'BinaryThresholdImageFilter im1.nii im1_thrbin.nii 0 100 1 0'
    >>> node.run() # doctest: +SKIP
    """

    input_spec = BinThreshInputSpec
    output_spec = BinThreshOutputSpec
    _cmd = 'BinaryThresholdImageFilter'


class BinThreshTask(DTITKRenameMixin, BinThresh):
    pass


class SVAdjustVoxSpTask(DTITKRenameMixin, SVAdjustVoxSp):
    pass


class SVResampleTask(DTITKRenameMixin, SVResample):
    pass


class TVAdjustOriginTask(DTITKRenameMixin, TVAdjustVoxSp):
    pass


class TVAdjustVoxSpTask(DTITKRenameMixin, TVAdjustVoxSp):
    pass


class TVResampleTask(DTITKRenameMixin, TVResample):
    pass


class TVtoolTask(DTITKRenameMixin, TVtool):
    pass



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import MRIsInflate


def test_MRIsInflate_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            copyfile=True,
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        no_save_sulc=dict(
            argstr='-no-save-sulc',
            xor=['out_sulc'],
        ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            hash_files=False,
            keep_extension=True,
            name_source=['in_file'],
            name_template='%s.inflated',
            position=-1,
        ),
        out_sulc=dict(
            extensions=None,
            xor=['no_save_sulc'],
        ),
        subjects_dir=dict(),
    )
    inputs = MRIsInflate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MRIsInflate_outputs():
    output_map = dict(
        out_file=dict(extensions=None, ),
        out_sulc=dict(extensions=None, ),
    )
    outputs = MRIsInflate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
from __future__ import (print_function, division, unicode_literals,
                        absolute_import)

from builtins import object
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:

import logging
from warnings import warn
import os
import sys
from .misc import str2bool

try:
    from ..external.cloghandler import ConcurrentRotatingFileHandler as \
        RFHandler
except ImportError:
    # Next 2 lines are optional:  issue a warning to the user
    warn("ConcurrentLogHandler not installed. Using builtin log handler")
    from logging.handlers import RotatingFileHandler as RFHandler


class Logging(object):
    """Nipype logging class
    """
    fmt = ('%(asctime)s,%(msecs)d %(name)-2s '
           '%(levelname)-2s:\n\t %(message)s')
    datefmt = '%y%m%d-%H:%M:%S'

    def __init__(self, config):
        self._config = config
        # scope our logger to not interfere with user
        _nipype_logger = logging.getLogger('nipype')
        _nipype_hdlr = logging.StreamHandler(stream=sys.stdout)
        _nipype_hdlr.setFormatter(logging.Formatter(fmt=self.fmt,
                                                    datefmt=self.datefmt))
        # if StreamHandler was added, do not stack
        if not len(_nipype_logger.handlers):
            _nipype_logger.addHandler(_nipype_hdlr)

        self._logger = logging.getLogger('nipype.workflow')
        self._utlogger = logging.getLogger('nipype.utils')
        self._fmlogger = logging.getLogger('nipype.filemanip')
        self._iflogger = logging.getLogger('nipype.interface')

        self.loggers = {
            'nipype.workflow': self._logger,
            'nipype.utils': self._utlogger,
            'nipype.filemanip': self._fmlogger,
            'nipype.interface': self._iflogger
        }
        self._hdlr = None
        self.update_logging(self._config)

    def enable_file_logging(self):
        config = self._config
        LOG_FILENAME = os.path.join(
            config.get('logging', 'log_directory'), 'pypeline.log')
        hdlr = RFHandler(
            LOG_FILENAME,
            maxBytes=int(config.get('logging', 'log_size')),
            backupCount=int(config.get('logging', 'log_rotate')))
        formatter = logging.Formatter(fmt=self.fmt, datefmt=self.datefmt)
        hdlr.setFormatter(formatter)
        self._logger.addHandler(hdlr)
        self._utlogger.addHandler(hdlr)
        self._iflogger.addHandler(hdlr)
        self._fmlogger.addHandler(hdlr)
        self._hdlr = hdlr

    def disable_file_logging(self):
        if self._hdlr:
            self._logger.removeHandler(self._hdlr)
            self._utlogger.removeHandler(self._hdlr)
            self._iflogger.removeHandler(self._hdlr)
            self._fmlogger.removeHandler(self._hdlr)
            self._hdlr = None

    def update_logging(self, config):
        self._config = config
        self.disable_file_logging()
        self._logger.setLevel(
            logging.getLevelName(config.get('logging', 'workflow_level')))
        self._utlogger.setLevel(
            logging.getLevelName(config.get('logging', 'utils_level')))
        self._iflogger.setLevel(
            logging.getLevelName(config.get('logging', 'interface_level')))
        if str2bool(config.get('logging', 'log_to_file')):
            self.enable_file_logging()

    def getLogger(self, name):
        if name == 'filemanip':
            warn('The "filemanip" logger has been deprecated and replaced by '
                 'the "utils" logger as of nipype 1.0')
        if name in self.loggers:
            return self.loggers[name]
        return None

    def getLevelName(self, name):
        return logging.getLevelName(name)

    def logdebug_dict_differences(self, dold, dnew, prefix=""):
        """Helper to log what actually changed from old to new values of
        dictionaries.

        typical use -- log difference for hashed_inputs
        """
        from .misc import dict_diff
        self._logger.warning(
            "logdebug_dict_differences has been deprecated, please use "
            "nipype.utils.misc.dict_diff.")
        self._logger.debug(dict_diff(dold, dnew))



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..brains import FindCenterOfBrain


def test_FindCenterOfBrain_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        axis=dict(argstr='--axis %d', ),
        backgroundValue=dict(argstr='--backgroundValue %d', ),
        clippedImageMask=dict(
            argstr='--clippedImageMask %s',
            hash_files=False,
        ),
        closingSize=dict(argstr='--closingSize %d', ),
        debugAfterGridComputationsForegroundImage=dict(
            argstr='--debugAfterGridComputationsForegroundImage %s',
            hash_files=False,
        ),
        debugClippedImageMask=dict(
            argstr='--debugClippedImageMask %s',
            hash_files=False,
        ),
        debugDistanceImage=dict(
            argstr='--debugDistanceImage %s',
            hash_files=False,
        ),
        debugGridImage=dict(
            argstr='--debugGridImage %s',
            hash_files=False,
        ),
        debugTrimmedImage=dict(
            argstr='--debugTrimmedImage %s',
            hash_files=False,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        generateDebugImages=dict(argstr='--generateDebugImages ', ),
        headSizeEstimate=dict(argstr='--headSizeEstimate %f', ),
        headSizeLimit=dict(argstr='--headSizeLimit %f', ),
        imageMask=dict(
            argstr='--imageMask %s',
            extensions=None,
        ),
        inputVolume=dict(
            argstr='--inputVolume %s',
            extensions=None,
        ),
        maximize=dict(argstr='--maximize ', ),
        otsuPercentileThreshold=dict(argstr='--otsuPercentileThreshold %f', ),
    )
    inputs = FindCenterOfBrain.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_FindCenterOfBrain_outputs():
    output_map = dict(
        clippedImageMask=dict(extensions=None, ),
        debugAfterGridComputationsForegroundImage=dict(extensions=None, ),
        debugClippedImageMask=dict(extensions=None, ),
        debugDistanceImage=dict(extensions=None, ),
        debugGridImage=dict(extensions=None, ),
        debugTrimmedImage=dict(extensions=None, ),
    )
    outputs = FindCenterOfBrain.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""Parallel workflow execution via IPython controller
"""
from __future__ import (print_function, division, unicode_literals,
                        absolute_import)

from future import standard_library
standard_library.install_aliases()
from future.utils import raise_from

from pickle import dumps

import sys
from .base import (DistributedPluginBase, logger, report_crash)

IPython_not_loaded = False
try:
    from IPython import __version__ as IPyversion
    from ipyparallel.error import TimeoutError
except:
    IPython_not_loaded = True


def execute_task(pckld_task, node_config, updatehash):
    from socket import gethostname
    from traceback import format_exc
    from nipype import config, logging
    traceback = None
    result = None
    import os
    cwd = os.getcwd()
    try:
        config.update_config(node_config)
        logging.update_logging(config)
        from pickle import loads
        task = loads(pckld_task)
        result = task.run(updatehash=updatehash)
    except:
        traceback = format_exc()
        from pickle import loads
        task = loads(pckld_task)
        result = task.result
    os.chdir(cwd)
    return result, traceback, gethostname()


class IPythonPlugin(DistributedPluginBase):
    """Execute workflow with ipython
    """

    def __init__(self, plugin_args=None):
        if IPython_not_loaded:
            raise ImportError('Please install ipyparallel to use this plugin.')
        super(IPythonPlugin, self).__init__(plugin_args=plugin_args)
        valid_args = ('url_file', 'profile', 'cluster_id', 'context', 'debug',
                      'timeout', 'config', 'username', 'sshserver', 'sshkey',
                      'password', 'paramiko')
        self.client_args = {
            arg: plugin_args[arg]
            for arg in valid_args if arg in plugin_args
        }
        self.iparallel = None
        self.taskclient = None
        self.taskmap = {}
        self._taskid = 0

    def run(self, graph, config, updatehash=False):
        """Executes a pre-defined pipeline is distributed approaches
        based on IPython's ipyparallel processing interface
        """
        # retrieve clients again
        try:
            name = 'ipyparallel'
            __import__(name)
            self.iparallel = sys.modules[name]
        except ImportError as e:
            raise_from(
                ImportError("ipyparallel not found. Parallel execution "
                            "will be unavailable"), e)
        try:
            self.taskclient = self.iparallel.Client(**self.client_args)
        except Exception as e:
            if isinstance(e, TimeoutError):
                raise_from(Exception("No IPython clients found."), e)
            if isinstance(e, IOError):
                raise_from(
                    Exception("ipcluster/ipcontroller has not been started"),
                    e)
            if isinstance(e, ValueError):
                raise_from(Exception("Ipython kernel not installed"), e)
            else:
                raise e
        return super(IPythonPlugin, self).run(
            graph, config, updatehash=updatehash)

    def _get_result(self, taskid):
        if taskid not in self.taskmap:
            raise ValueError('Task %d not in pending list' % taskid)
        if self.taskmap[taskid].ready():
            result, traceback, hostname = self.taskmap[taskid].get()
            result_out = dict(result=None, traceback=None)
            result_out['result'] = result
            result_out['traceback'] = traceback
            result_out['hostname'] = hostname
            return result_out
        else:
            return None

    def _submit_job(self, node, updatehash=False):
        pckld_node = dumps(node, 2)
        result_object = self.taskclient.load_balanced_view().apply(
            execute_task, pckld_node, node.config, updatehash)
        self._taskid += 1
        self.taskmap[self._taskid] = result_object
        return self._taskid

    def _report_crash(self, node, result=None):
        if result and result['traceback']:
            node._result = result['result']
            node._traceback = result['traceback']
            return report_crash(node, traceback=result['traceback'])
        else:
            return report_crash(node)

    def _clear_task(self, taskid):
        if IPyversion >= '0.11':
            logger.debug("Clearing id: %d" % taskid)
            self.taskclient.purge_results(self.taskmap[taskid])
            del self.taskmap[taskid]



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""
# changing to temporary directories
    >>> tmp = getfixture('tmpdir')
    >>> old = tmp.chdir()
"""

from __future__ import (print_function, division, unicode_literals,
                        absolute_import)

from future import standard_library
standard_library.install_aliases()

from builtins import str, bytes

from ... import logging
from ..base import (traits, DynamicTraitedSpec, Undefined, isdefined,
                    BaseInterfaceInputSpec)
from ..io import IOBase, add_traits
from ...utils.filemanip import ensure_list
from ...utils.functions import getsource, create_function_from_source

iflogger = logging.getLogger('nipype.interface')


class FunctionInputSpec(DynamicTraitedSpec, BaseInterfaceInputSpec):
    function_str = traits.Str(mandatory=True, desc='code for function')


class Function(IOBase):
    """Runs arbitrary function as an interface

    Examples
    --------

    >>> func = 'def func(arg1, arg2=5): return arg1 + arg2'
    >>> fi = Function(input_names=['arg1', 'arg2'], output_names=['out'])
    >>> fi.inputs.function_str = func
    >>> res = fi.run(arg1=1)
    >>> res.outputs.out
    6

    """

    input_spec = FunctionInputSpec
    output_spec = DynamicTraitedSpec

    def __init__(self,
                 input_names=None,
                 output_names='out',
                 function=None,
                 imports=None,
                 **inputs):
        """

        Parameters
        ----------

        input_names: single str or list or None
            names corresponding to function inputs
            if ``None``, derive input names from function argument names
        output_names: single str or list
            names corresponding to function outputs (default: 'out').
            if list of length > 1, has to match the number of outputs
        function : callable
            callable python object. must be able to execute in an
            isolated namespace (possibly in concert with the ``imports``
            parameter)
        imports : list of strings
            list of import statements that allow the function to execute
            in an otherwise empty namespace
        """

        super(Function, self).__init__(**inputs)
        if function:
            if hasattr(function, '__call__'):
                try:
                    self.inputs.function_str = getsource(function)
                except IOError:
                    raise Exception('Interface Function does not accept '
                                    'function objects defined interactively '
                                    'in a python session')
                else:
                    if input_names is None:
                        fninfo = function.__code__
            elif isinstance(function, (str, bytes)):
                self.inputs.function_str = function
                if input_names is None:
                    fninfo = create_function_from_source(function,
                                                         imports).__code__
            else:
                raise Exception('Unknown type of function')
            if input_names is None:
                input_names = fninfo.co_varnames[:fninfo.co_argcount]
        self.inputs.on_trait_change(self._set_function_string, 'function_str')
        self._input_names = ensure_list(input_names)
        self._output_names = ensure_list(output_names)
        add_traits(self.inputs, [name for name in self._input_names])
        self.imports = imports
        self._out = {}
        for name in self._output_names:
            self._out[name] = None

    def _set_function_string(self, obj, name, old, new):
        if name == 'function_str':
            if hasattr(new, '__call__'):
                function_source = getsource(new)
                fninfo = new.__code__
            elif isinstance(new, (str, bytes)):
                function_source = new
                fninfo = create_function_from_source(new,
                                                     self.imports).__code__
            self.inputs.trait_set(
                trait_change_notify=False, **{
                    '%s' % name: function_source
                })
            # Update input traits
            input_names = fninfo.co_varnames[:fninfo.co_argcount]
            new_names = set(input_names) - set(self._input_names)
            add_traits(self.inputs, list(new_names))
            self._input_names.extend(new_names)

    def _add_output_traits(self, base):
        undefined_traits = {}
        for key in self._output_names:
            base.add_trait(key, traits.Any)
            undefined_traits[key] = Undefined
        base.trait_set(trait_change_notify=False, **undefined_traits)
        return base

    def _run_interface(self, runtime):
        # Create function handle
        function_handle = create_function_from_source(self.inputs.function_str,
                                                      self.imports)
        # Get function args
        args = {}
        for name in self._input_names:
            value = getattr(self.inputs, name)
            if isdefined(value):
                args[name] = value

        out = function_handle(**args)
        if len(self._output_names) == 1:
            self._out[self._output_names[0]] = out
        else:
            if isinstance(out, tuple) and \
                    (len(out) != len(self._output_names)):
                raise RuntimeError('Mismatch in number of expected outputs')

            else:
                for idx, name in enumerate(self._output_names):
                    self._out[name] = out[idx]

        return runtime

    def _list_outputs(self):
        outputs = self._outputs().get()
        for key in self._output_names:
            outputs[key] = self._out[key]
        return outputs



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import BlurToFWHM


def test_BlurToFWHM_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        automask=dict(argstr='-automask', ),
        blurmaster=dict(
            argstr='-blurmaster %s',
            extensions=None,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        fwhm=dict(argstr='-FWHM %f', ),
        fwhmxy=dict(argstr='-FWHMxy %f', ),
        in_file=dict(
            argstr='-input %s',
            extensions=None,
            mandatory=True,
        ),
        mask=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source=['in_file'],
            name_template='%s_afni',
        ),
        outputtype=dict(),
    )
    inputs = BlurToFWHM.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BlurToFWHM_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = BlurToFWHM.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import TCorr1D


def test_TCorr1D_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        ktaub=dict(
            argstr=' -ktaub',
            position=1,
            xor=['pearson', 'spearman', 'quadrant'],
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            keep_extension=True,
            name_source='xset',
            name_template='%s_correlation.nii.gz',
        ),
        outputtype=dict(),
        pearson=dict(
            argstr=' -pearson',
            position=1,
            xor=['spearman', 'quadrant', 'ktaub'],
        ),
        quadrant=dict(
            argstr=' -quadrant',
            position=1,
            xor=['pearson', 'spearman', 'ktaub'],
        ),
        spearman=dict(
            argstr=' -spearman',
            position=1,
            xor=['pearson', 'quadrant', 'ktaub'],
        ),
        xset=dict(
            argstr=' %s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        y_1d=dict(
            argstr=' %s',
            extensions=None,
            mandatory=True,
            position=-1,
        ),
    )
    inputs = TCorr1D.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_TCorr1D_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = TCorr1D.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import SmoothTessellation


def test_SmoothTessellation_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        curvature_averaging_iterations=dict(argstr='-a %d', ),
        disable_estimates=dict(argstr='-nw', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        gaussian_curvature_norm_steps=dict(argstr='%d ', ),
        gaussian_curvature_smoothing_steps=dict(argstr='%d', ),
        in_file=dict(
            argstr='%s',
            copyfile=True,
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        normalize_area=dict(argstr='-area', ),
        out_area_file=dict(
            argstr='-b %s',
            extensions=None,
        ),
        out_curvature_file=dict(
            argstr='-c %s',
            extensions=None,
        ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        seed=dict(argstr='-seed %d', ),
        smoothing_iterations=dict(argstr='-n %d', ),
        snapshot_writing_iterations=dict(argstr='-w %d', ),
        subjects_dir=dict(),
        use_gaussian_curvature_smoothing=dict(argstr='-g', ),
        use_momentum=dict(argstr='-m', ),
    )
    inputs = SmoothTessellation.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_SmoothTessellation_outputs():
    output_map = dict(surface=dict(extensions=None, ), )
    outputs = SmoothTessellation.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
import os

import pytest
from nipype.testing.fixtures import create_files_in_directory

import nipype.interfaces.fsl.epi as fsl
from nipype.interfaces.fsl import no_fsl


# test eddy_correct
@pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
def test_eddy_correct2(create_files_in_directory):
    filelist, outdir = create_files_in_directory
    eddy = fsl.EddyCorrect()

    # make sure command gets called
    assert eddy.cmd == 'eddy_correct'

    # test raising error with mandatory args absent
    with pytest.raises(ValueError):
        eddy.run()

    # .inputs based parameters setting
    eddy.inputs.in_file = filelist[0]
    eddy.inputs.out_file = 'foo_eddc.nii'
    eddy.inputs.ref_num = 100
    assert eddy.cmdline == 'eddy_correct %s foo_eddc.nii 100' % filelist[0]

    # .run based parameter setting
    eddy2 = fsl.EddyCorrect(
        in_file=filelist[0], out_file='foo_ec.nii', ref_num=20)
    assert eddy2.cmdline == 'eddy_correct %s foo_ec.nii 20' % filelist[0]

    # test arguments for opt_map
    # eddy_correct class doesn't have opt_map{}



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import TensorMetrics


def test_TensorMetrics_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        component=dict(
            argstr='-num %s',
            sep=',',
            usedefault=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        in_mask=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        modulate=dict(argstr='-modulate %s', ),
        out_adc=dict(
            argstr='-adc %s',
            extensions=None,
        ),
        out_eval=dict(
            argstr='-value %s',
            extensions=None,
        ),
        out_evec=dict(
            argstr='-vector %s',
            extensions=None,
        ),
        out_fa=dict(
            argstr='-fa %s',
            extensions=None,
        ),
    )
    inputs = TensorMetrics.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_TensorMetrics_outputs():
    output_map = dict(
        out_adc=dict(extensions=None, ),
        out_eval=dict(extensions=None, ),
        out_evec=dict(extensions=None, ),
        out_fa=dict(extensions=None, ),
    )
    outputs = TensorMetrics.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
# -*- coding: utf-8 -*-
from __future__ import (print_function, division, unicode_literals,
                        absolute_import)

import os.path as op

from ..base import traits, TraitedSpec, File, Undefined, InputMultiObject
from .base import MRTrix3BaseInputSpec, MRTrix3Base


class FitTensorInputSpec(MRTrix3BaseInputSpec):
    in_file = File(
        exists=True,
        argstr='%s',
        mandatory=True,
        position=-2,
        desc='input diffusion weighted images')
    out_file = File(
        'dti.mif',
        argstr='%s',
        mandatory=True,
        position=-1,
        usedefault=True,
        desc='the output diffusion tensor image')

    # General options
    in_mask = File(
        exists=True,
        argstr='-mask %s',
        desc=('only perform computation within the specified '
              'binary brain mask image'))
    method = traits.Enum(
        'nonlinear',
        'loglinear',
        'sech',
        'rician',
        argstr='-method %s',
        desc=('select method used to perform the fitting'))
    reg_term = traits.Float(
        argstr='-regularisation %f',
        max_ver='0.3.13',
        desc=('specify the strength of the regularisation term on the '
              'magnitude of the tensor elements (default = 5000). This '
              'only applies to the non-linear methods'))


class FitTensorOutputSpec(TraitedSpec):
    out_file = File(exists=True, desc='the output DTI file')


class FitTensor(MRTrix3Base):
    """
    Convert diffusion-weighted images to tensor images


    Example
    -------

    >>> import nipype.interfaces.mrtrix3 as mrt
    >>> tsr = mrt.FitTensor()
    >>> tsr.inputs.in_file = 'dwi.mif'
    >>> tsr.inputs.in_mask = 'mask.nii.gz'
    >>> tsr.inputs.grad_fsl = ('bvecs', 'bvals')
    >>> tsr.cmdline                               # doctest: +ELLIPSIS
    'dwi2tensor -fslgrad bvecs bvals -mask mask.nii.gz dwi.mif dti.mif'
    >>> tsr.run()                                 # doctest: +SKIP
    """

    _cmd = 'dwi2tensor'
    input_spec = FitTensorInputSpec
    output_spec = FitTensorOutputSpec

    def _list_outputs(self):
        outputs = self.output_spec().get()
        outputs['out_file'] = op.abspath(self.inputs.out_file)
        return outputs


class EstimateFODInputSpec(MRTrix3BaseInputSpec):
    algorithm = traits.Enum(
        'csd',
        'msmt_csd',
        argstr='%s',
        position=-8,
        mandatory=True,
        desc='FOD algorithm')
    in_file = File(
        exists=True,
        argstr='%s',
        position=-7,
        mandatory=True,
        desc='input DWI image')
    wm_txt = File(
        argstr='%s', position=-6, mandatory=True, desc='WM response text file')
    wm_odf = File(
        'wm.mif',
        argstr='%s',
        position=-5,
        usedefault=True,
        mandatory=True,
        desc='output WM ODF')
    gm_txt = File(argstr='%s', position=-4, desc='GM response text file')
    gm_odf = File('gm.mif', usedefault=True, argstr='%s',
                  position=-3, desc='output GM ODF')
    csf_txt = File(argstr='%s', position=-2, desc='CSF response text file')
    csf_odf = File('csf.mif', usedefault=True, argstr='%s',
                   position=-1, desc='output CSF ODF')
    mask_file = File(exists=True, argstr='-mask %s', desc='mask image')

    # DW Shell selection options
    shell = traits.List(
        traits.Float,
        sep=',',
        argstr='-shell %s',
        desc='specify one or more dw gradient shells')
    max_sh = InputMultiObject(
        traits.Int,
        value=[8],
        usedefault=True,
        argstr='-lmax %s',
        sep=',',
        desc=('maximum harmonic degree of response function - single value for single-shell response, list for multi-shell response'))
    in_dirs = File(
        exists=True,
        argstr='-directions %s',
        desc=('specify the directions over which to apply the non-negativity '
              'constraint (by default, the built-in 300 direction set is '
              'used). These should be supplied as a text file containing the '
              '[ az el ] pairs for the directions.'))


class EstimateFODOutputSpec(TraitedSpec):
    wm_odf = File(argstr='%s', desc='output WM ODF')
    gm_odf = File(argstr='%s', desc='output GM ODF')
    csf_odf = File(argstr='%s', desc='output CSF ODF')


class EstimateFOD(MRTrix3Base):
    """
    Estimate fibre orientation distributions from diffusion data using spherical deconvolution

    Example
    -------

    >>> import nipype.interfaces.mrtrix3 as mrt
    >>> fod = mrt.EstimateFOD()
    >>> fod.inputs.algorithm = 'csd'
    >>> fod.inputs.in_file = 'dwi.mif'
    >>> fod.inputs.wm_txt = 'wm.txt'
    >>> fod.inputs.grad_fsl = ('bvecs', 'bvals')
    >>> fod.cmdline                               # doctest: +ELLIPSIS
    'dwi2fod -fslgrad bvecs bvals -lmax 8 csd dwi.mif wm.txt wm.mif gm.mif csf.mif'
    >>> fod.run()                                 # doctest: +SKIP
    """

    _cmd = 'dwi2fod'
    input_spec = EstimateFODInputSpec
    output_spec = EstimateFODOutputSpec

    def _list_outputs(self):
        outputs = self.output_spec().get()
        outputs['wm_odf'] = op.abspath(self.inputs.wm_odf)
        if self.inputs.gm_odf != Undefined:
            outputs['gm_odf'] = op.abspath(self.inputs.gm_odf)
        if self.inputs.csf_odf != Undefined:
            outputs['csf_odf'] = op.abspath(self.inputs.csf_odf)
        return outputs



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..model import Cluster


def test_Cluster_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        connectivity=dict(argstr='--connectivity=%d', ),
        cope_file=dict(
            argstr='--cope=%s',
            extensions=None,
        ),
        dlh=dict(argstr='--dlh=%.10f', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        find_min=dict(
            argstr='--min',
            usedefault=True,
        ),
        fractional=dict(
            argstr='--fractional',
            usedefault=True,
        ),
        in_file=dict(
            argstr='--in=%s',
            extensions=None,
            mandatory=True,
        ),
        minclustersize=dict(
            argstr='--minclustersize',
            usedefault=True,
        ),
        no_table=dict(
            argstr='--no_table',
            usedefault=True,
        ),
        num_maxima=dict(argstr='--num=%d', ),
        out_index_file=dict(
            argstr='--oindex=%s',
            hash_files=False,
        ),
        out_localmax_txt_file=dict(
            argstr='--olmax=%s',
            hash_files=False,
        ),
        out_localmax_vol_file=dict(
            argstr='--olmaxim=%s',
            hash_files=False,
        ),
        out_max_file=dict(
            argstr='--omax=%s',
            hash_files=False,
        ),
        out_mean_file=dict(
            argstr='--omean=%s',
            hash_files=False,
        ),
        out_pval_file=dict(
            argstr='--opvals=%s',
            hash_files=False,
        ),
        out_size_file=dict(
            argstr='--osize=%s',
            hash_files=False,
        ),
        out_threshold_file=dict(
            argstr='--othresh=%s',
            hash_files=False,
        ),
        output_type=dict(),
        peak_distance=dict(argstr='--peakdist=%.10f', ),
        pthreshold=dict(
            argstr='--pthresh=%.10f',
            requires=['dlh', 'volume'],
        ),
        std_space_file=dict(
            argstr='--stdvol=%s',
            extensions=None,
        ),
        threshold=dict(
            argstr='--thresh=%.10f',
            mandatory=True,
        ),
        use_mm=dict(
            argstr='--mm',
            usedefault=True,
        ),
        volume=dict(argstr='--volume=%d', ),
        warpfield_file=dict(
            argstr='--warpvol=%s',
            extensions=None,
        ),
        xfm_file=dict(
            argstr='--xfm=%s',
            extensions=None,
        ),
    )
    inputs = Cluster.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Cluster_outputs():
    output_map = dict(
        index_file=dict(extensions=None, ),
        localmax_txt_file=dict(extensions=None, ),
        localmax_vol_file=dict(extensions=None, ),
        max_file=dict(extensions=None, ),
        mean_file=dict(extensions=None, ),
        pval_file=dict(extensions=None, ),
        size_file=dict(extensions=None, ),
        threshold_file=dict(extensions=None, ),
    )
    outputs = Cluster.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import Cat


def test_Cat_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_files=dict(
            argstr='%s',
            mandatory=True,
            position=-2,
        ),
        keepfree=dict(argstr='-nonfixed', ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        omitconst=dict(argstr='-nonconst', ),
        out_cint=dict(xor=[
            'out_format', 'out_nice', 'out_double', 'out_fint', 'out_int'
        ], ),
        out_double=dict(
            argstr='-d',
            xor=['out_format', 'out_nice', 'out_int', 'out_fint', 'out_cint'],
        ),
        out_file=dict(
            argstr='> %s',
            extensions=None,
            mandatory=True,
            position=-1,
            usedefault=True,
        ),
        out_fint=dict(
            argstr='-f',
            xor=[
                'out_format', 'out_nice', 'out_double', 'out_int', 'out_cint'
            ],
        ),
        out_format=dict(
            argstr='-form %s',
            xor=['out_int', 'out_nice', 'out_double', 'out_fint', 'out_cint'],
        ),
        out_int=dict(
            argstr='-i',
            xor=[
                'out_format', 'out_nice', 'out_double', 'out_fint', 'out_cint'
            ],
        ),
        out_nice=dict(
            argstr='-n',
            xor=[
                'out_format', 'out_int', 'out_double', 'out_fint', 'out_cint'
            ],
        ),
        outputtype=dict(),
        sel=dict(argstr='-sel %s', ),
        stack=dict(argstr='-stack', ),
    )
    inputs = Cat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Cat_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Cat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import ROIStats


def test_ROIStats_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        debug=dict(argstr='-debug', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        format1D=dict(
            argstr='-1Dformat',
            xor=['format1DR'],
        ),
        format1DR=dict(
            argstr='-1DRformat',
            xor=['format1D'],
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        mask=dict(
            argstr='-mask %s',
            deprecated='1.1.4',
            extensions=None,
            new_name='mask_file',
            position=3,
        ),
        mask_f2short=dict(argstr='-mask_f2short', ),
        mask_file=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        nobriklab=dict(argstr='-nobriklab', ),
        nomeanout=dict(argstr='-nomeanout', ),
        num_roi=dict(argstr='-numroi %s', ),
        out_file=dict(
            argstr='> %s',
            extensions=None,
            keep_extension=False,
            name_source='in_file',
            name_template='%s_roistat.1D',
            position=-1,
        ),
        quiet=dict(argstr='-quiet', ),
        roisel=dict(
            argstr='-roisel %s',
            extensions=None,
        ),
        stat=dict(argstr='%s...', ),
        zerofill=dict(
            argstr='-zerofill %s',
            requires=['num_roi'],
        ),
    )
    inputs = ROIStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ROIStats_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = ROIStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..nbs import NetworkBasedStatistic


def test_NetworkBasedStatistic_inputs():
    input_map = dict(
        edge_key=dict(usedefault=True, ),
        in_group1=dict(mandatory=True, ),
        in_group2=dict(mandatory=True, ),
        node_position_network=dict(extensions=None, ),
        number_of_permutations=dict(usedefault=True, ),
        out_nbs_network=dict(extensions=None, ),
        out_nbs_pval_network=dict(extensions=None, ),
        t_tail=dict(usedefault=True, ),
        threshold=dict(usedefault=True, ),
    )
    inputs = NetworkBasedStatistic.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_NetworkBasedStatistic_outputs():
    output_map = dict(
        nbs_network=dict(extensions=None, ),
        nbs_pval_network=dict(extensions=None, ),
        network_files=dict(),
    )
    outputs = NetworkBasedStatistic.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..tensors import FindShPeaks


def test_FindShPeaks_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        directions_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        display_debug=dict(argstr='-debug', ),
        display_info=dict(argstr='-info', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-3,
        ),
        num_peaks=dict(argstr='-num %s', ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            hash_files=False,
            keep_extension=False,
            name_source=['in_file'],
            name_template='%s_peak_dirs.mif',
            position=-1,
        ),
        peak_directions=dict(
            argstr='-direction %s',
            sep=' ',
        ),
        peak_threshold=dict(argstr='-threshold %s', ),
        peaks_image=dict(
            argstr='-peaks %s',
            extensions=None,
        ),
        quiet_display=dict(argstr='-quiet', ),
    )
    inputs = FindShPeaks.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_FindShPeaks_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = FindShPeaks.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import MRIConvert


def test_MRIConvert_inputs():
    input_map = dict(
        apply_inv_transform=dict(
            argstr='--apply_inverse_transform %s',
            extensions=None,
        ),
        apply_transform=dict(
            argstr='--apply_transform %s',
            extensions=None,
        ),
        args=dict(argstr='%s', ),
        ascii=dict(argstr='--ascii', ),
        autoalign_matrix=dict(
            argstr='--autoalign %s',
            extensions=None,
        ),
        color_file=dict(
            argstr='--color_file %s',
            extensions=None,
        ),
        conform=dict(argstr='--conform', ),
        conform_min=dict(argstr='--conform_min', ),
        conform_size=dict(argstr='--conform_size %s', ),
        crop_center=dict(argstr='--crop %d %d %d', ),
        crop_gdf=dict(argstr='--crop_gdf', ),
        crop_size=dict(argstr='--cropsize %d %d %d', ),
        cut_ends=dict(argstr='--cutends %d', ),
        cw256=dict(argstr='--cw256', ),
        devolve_transform=dict(argstr='--devolvexfm %s', ),
        drop_n=dict(argstr='--ndrop %d', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        fill_parcellation=dict(argstr='--fill_parcellation', ),
        force_ras=dict(argstr='--force_ras_good', ),
        frame=dict(argstr='--frame %d', ),
        frame_subsample=dict(argstr='--fsubsample %d %d %d', ),
        fwhm=dict(argstr='--fwhm %f', ),
        in_center=dict(argstr='--in_center %s', ),
        in_file=dict(
            argstr='--input_volume %s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        in_i_dir=dict(argstr='--in_i_direction %f %f %f', ),
        in_i_size=dict(argstr='--in_i_size %d', ),
        in_info=dict(argstr='--in_info', ),
        in_j_dir=dict(argstr='--in_j_direction %f %f %f', ),
        in_j_size=dict(argstr='--in_j_size %d', ),
        in_k_dir=dict(argstr='--in_k_direction %f %f %f', ),
        in_k_size=dict(argstr='--in_k_size %d', ),
        in_like=dict(
            argstr='--in_like %s',
            extensions=None,
        ),
        in_matrix=dict(argstr='--in_matrix', ),
        in_orientation=dict(argstr='--in_orientation %s', ),
        in_scale=dict(argstr='--scale %f', ),
        in_stats=dict(argstr='--in_stats', ),
        in_type=dict(argstr='--in_type %s', ),
        invert_contrast=dict(argstr='--invert_contrast %f', ),
        midframe=dict(argstr='--mid-frame', ),
        no_change=dict(argstr='--nochange', ),
        no_scale=dict(argstr='--no_scale 1', ),
        no_translate=dict(argstr='--no_translate', ),
        no_write=dict(argstr='--no_write', ),
        out_center=dict(argstr='--out_center %f %f %f', ),
        out_datatype=dict(argstr='--out_data_type %s', ),
        out_file=dict(
            argstr='--output_volume %s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        out_i_count=dict(argstr='--out_i_count %d', ),
        out_i_dir=dict(argstr='--out_i_direction %f %f %f', ),
        out_i_size=dict(argstr='--out_i_size %d', ),
        out_info=dict(argstr='--out_info', ),
        out_j_count=dict(argstr='--out_j_count %d', ),
        out_j_dir=dict(argstr='--out_j_direction %f %f %f', ),
        out_j_size=dict(argstr='--out_j_size %d', ),
        out_k_count=dict(argstr='--out_k_count %d', ),
        out_k_dir=dict(argstr='--out_k_direction %f %f %f', ),
        out_k_size=dict(argstr='--out_k_size %d', ),
        out_matrix=dict(argstr='--out_matrix', ),
        out_orientation=dict(argstr='--out_orientation %s', ),
        out_scale=dict(argstr='--out-scale %d', ),
        out_stats=dict(argstr='--out_stats', ),
        out_type=dict(argstr='--out_type %s', ),
        parse_only=dict(argstr='--parse_only', ),
        read_only=dict(argstr='--read_only', ),
        reorder=dict(argstr='--reorder %d %d %d', ),
        resample_type=dict(argstr='--resample_type %s', ),
        reslice_like=dict(
            argstr='--reslice_like %s',
            extensions=None,
        ),
        sdcm_list=dict(
            argstr='--sdcmlist %s',
            extensions=None,
        ),
        skip_n=dict(argstr='--nskip %d', ),
        slice_bias=dict(argstr='--slice-bias %f', ),
        slice_crop=dict(argstr='--slice-crop %d %d', ),
        slice_reverse=dict(argstr='--slice-reverse', ),
        smooth_parcellation=dict(argstr='--smooth_parcellation', ),
        sphinx=dict(argstr='--sphinx', ),
        split=dict(argstr='--split', ),
        status_file=dict(
            argstr='--status %s',
            extensions=None,
        ),
        subject_name=dict(argstr='--subject_name %s', ),
        subjects_dir=dict(),
        te=dict(argstr='-te %d', ),
        template_info=dict(argstr='--template_info', ),
        template_type=dict(argstr='--template_type %s', ),
        ti=dict(argstr='-ti %d', ),
        tr=dict(argstr='-tr %d', ),
        unwarp_gradient=dict(argstr='--unwarp_gradient_nonlinearity', ),
        vox_size=dict(argstr='-voxsize %f %f %f', ),
        zero_ge_z_offset=dict(argstr='--zero_ge_z_offset', ),
        zero_outlines=dict(argstr='--zero_outlines', ),
    )
    inputs = MRIConvert.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MRIConvert_outputs():
    output_map = dict(out_file=dict(), )
    outputs = MRIConvert.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..dti import DTMetric


def test_DTMetric_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        data_header=dict(
            argstr='-header %s',
            extensions=None,
        ),
        eigen_data=dict(
            argstr='-inputfile %s',
            extensions=None,
            mandatory=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputdatatype=dict(
            argstr='-inputdatatype %s',
            usedefault=True,
        ),
        metric=dict(
            argstr='-stat %s',
            mandatory=True,
        ),
        outputdatatype=dict(
            argstr='-outputdatatype %s',
            usedefault=True,
        ),
        outputfile=dict(
            argstr='-outputfile %s',
            extensions=None,
            genfile=True,
        ),
    )
    inputs = DTMetric.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_DTMetric_outputs():
    output_map = dict(metric_stats=dict(extensions=None, ), )
    outputs = DTMetric.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import Zeropad


def test_Zeropad_inputs():
    input_map = dict(
        A=dict(
            argstr='-A %i',
            xor=['master'],
        ),
        AP=dict(
            argstr='-AP %i',
            xor=['master'],
        ),
        I=dict(
            argstr='-I %i',
            xor=['master'],
        ),
        IS=dict(
            argstr='-IS %i',
            xor=['master'],
        ),
        L=dict(
            argstr='-L %i',
            xor=['master'],
        ),
        P=dict(
            argstr='-P %i',
            xor=['master'],
        ),
        R=dict(
            argstr='-R %i',
            xor=['master'],
        ),
        RL=dict(
            argstr='-RL %i',
            xor=['master'],
        ),
        S=dict(
            argstr='-S %i',
            xor=['master'],
        ),
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_files=dict(
            argstr='%s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        master=dict(
            argstr='-master %s',
            extensions=None,
            xor=['I', 'S', 'A', 'P', 'L', 'R', 'z', 'RL', 'AP', 'IS', 'mm'],
        ),
        mm=dict(
            argstr='-mm',
            xor=['master'],
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_template='zeropad',
        ),
        outputtype=dict(),
        z=dict(
            argstr='-z %i',
            xor=['master'],
        ),
    )
    inputs = Zeropad.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Zeropad_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Zeropad.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..odf import LinRecon


def test_LinRecon_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        bgmask=dict(
            argstr='-bgmask %s',
            extensions=None,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        log=dict(argstr='-log', ),
        normalize=dict(argstr='-normalize', ),
        out_file=dict(
            argstr='> %s',
            extensions=None,
            genfile=True,
            position=-1,
        ),
        qball_mat=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=3,
        ),
        scheme_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=2,
        ),
    )
    inputs = LinRecon.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_LinRecon_outputs():
    output_map = dict(recon_data=dict(extensions=None, ), )
    outputs = LinRecon.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
from .brainsuite import (Bse, Bfc, Pvc, Cerebro, Cortex, Scrubmask, Tca,
                         Dewisp, Dfs, Pialmesh, Skullfinder, Hemisplit, SVReg,
                         BDP, ThicknessPVC)



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import BET


def test_BET_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        center=dict(
            argstr='-c %s',
            units='voxels',
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        frac=dict(argstr='-f %.2f', ),
        functional=dict(
            argstr='-F',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=0,
        ),
        mask=dict(argstr='-m', ),
        mesh=dict(argstr='-e', ),
        no_output=dict(argstr='-n', ),
        out_file=dict(
            argstr='%s',
            extensions=None,
            genfile=True,
            hash_files=False,
            position=1,
        ),
        outline=dict(argstr='-o', ),
        output_type=dict(),
        padding=dict(
            argstr='-Z',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        radius=dict(
            argstr='-r %d',
            units='mm',
        ),
        reduce_bias=dict(
            argstr='-B',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        remove_eyes=dict(
            argstr='-S',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        robust=dict(
            argstr='-R',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        skull=dict(argstr='-s', ),
        surfaces=dict(
            argstr='-A',
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        t2_guided=dict(
            argstr='-A2 %s',
            extensions=None,
            xor=('functional', 'reduce_bias', 'robust', 'padding',
                 'remove_eyes', 'surfaces', 't2_guided'),
        ),
        threshold=dict(argstr='-t', ),
        vertical_gradient=dict(argstr='-g %.2f', ),
    )
    inputs = BET.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_BET_outputs():
    output_map = dict(
        inskull_mask_file=dict(extensions=None, ),
        inskull_mesh_file=dict(extensions=None, ),
        mask_file=dict(extensions=None, ),
        meshfile=dict(extensions=None, ),
        out_file=dict(extensions=None, ),
        outline_file=dict(extensions=None, ),
        outskin_mask_file=dict(extensions=None, ),
        outskin_mesh_file=dict(extensions=None, ),
        outskull_mask_file=dict(extensions=None, ),
        outskull_mesh_file=dict(extensions=None, ),
        skull_mask_file=dict(extensions=None, ),
    )
    outputs = BET.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..stats import UnaryStats


def test_UnaryStats_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=2,
        ),
        larger_voxel=dict(
            argstr='-t %f',
            position=-3,
        ),
        mask_file=dict(
            argstr='-m %s',
            extensions=None,
            position=-2,
        ),
        operation=dict(
            argstr='-%s',
            mandatory=True,
            position=4,
        ),
    )
    inputs = UnaryStats.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_UnaryStats_outputs():
    output_map = dict(output=dict(), )
    outputs = UnaryStats.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import TShift


def test_TShift_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        ignore=dict(argstr='-ignore %s', ),
        in_file=dict(
            argstr='%s',
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        interp=dict(argstr='-%s', ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr='-prefix %s',
            extensions=None,
            name_source='in_file',
            name_template='%s_tshift',
        ),
        outputtype=dict(),
        rlt=dict(argstr='-rlt', ),
        rltplus=dict(argstr='-rlt+', ),
        slice_encoding_direction=dict(usedefault=True, ),
        slice_timing=dict(
            argstr='-tpattern @%s',
            xor=['tpattern'],
        ),
        tpattern=dict(
            argstr='-tpattern %s',
            xor=['slice_timing'],
        ),
        tr=dict(argstr='-TR %s', ),
        tslice=dict(
            argstr='-slice %s',
            xor=['tzero'],
        ),
        tzero=dict(
            argstr='-tzero %s',
            xor=['tslice'],
        ),
    )
    inputs = TShift.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_TShift_outputs():
    output_map = dict(
        out_file=dict(extensions=None, ),
        timing_file=dict(extensions=None, ),
    )
    outputs = TShift.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..utils import Refit


def test_Refit_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        atrcopy=dict(argstr='-atrcopy %s %s', ),
        atrfloat=dict(argstr='-atrfloat %s %s', ),
        atrint=dict(argstr='-atrint %s %s', ),
        atrstring=dict(argstr='-atrstring %s %s', ),
        deoblique=dict(argstr='-deoblique', ),
        duporigin_file=dict(
            argstr='-duporigin %s',
            extensions=None,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr='%s',
            copyfile=True,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        nosaveatr=dict(argstr='-nosaveatr', ),
        saveatr=dict(argstr='-saveatr', ),
        space=dict(argstr='-space %s', ),
        xdel=dict(argstr='-xdel %f', ),
        xorigin=dict(argstr='-xorigin %s', ),
        xyzscale=dict(argstr='-xyzscale %f', ),
        ydel=dict(argstr='-ydel %f', ),
        yorigin=dict(argstr='-yorigin %s', ),
        zdel=dict(argstr='-zdel %f', ),
        zorigin=dict(argstr='-zorigin %s', ),
    )
    inputs = Refit.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_Refit_outputs():
    output_map = dict(out_file=dict(extensions=None, ), )
    outputs = Refit.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
from __future__ import unicode_literals
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
from builtins import open

import os

import pytest
import nipype.interfaces.fsl.model as fsl
from nipype.interfaces.fsl import no_fsl


@pytest.mark.skipif(no_fsl(), reason="fsl is not installed")
def test_MultipleRegressDesign(tmpdir):
    tmpdir.chdir()
    foo = fsl.MultipleRegressDesign()
    foo.inputs.regressors = dict(
        voice_stenght=[1, 1, 1], age=[0.2, 0.4, 0.5], BMI=[1, -1, 2])
    con1 = ['voice_and_age', 'T', ['age', 'voice_stenght'], [0.5, 0.5]]
    con2 = ['just_BMI', 'T', ['BMI'], [1]]
    foo.inputs.contrasts = [con1, con2, ['con3', 'F', [con1, con2]]]
    res = foo.run()

    for ii in ["mat", "con", "fts", "grp"]:
        assert getattr(res.outputs,
                       "design_" + ii) == tmpdir.join('design.' + ii).strpath

    design_mat_expected_content = """/NumWaves       3
/NumPoints      3
/PPheights      3.000000e+00 5.000000e-01 1.000000e+00

/Matrix
1.000000e+00 2.000000e-01 1.000000e+00
-1.000000e+00 4.000000e-01 1.000000e+00
2.000000e+00 5.000000e-01 1.000000e+00
"""

    design_con_expected_content = """/ContrastName1   voice_and_age
/ContrastName2   just_BMI
/NumWaves       3
/NumContrasts   2
/PPheights          1.000000e+00 1.000000e+00
/RequiredEffect     100.000 100.000

/Matrix
0.000000e+00 5.000000e-01 5.000000e-01
1.000000e+00 0.000000e+00 0.000000e+00
"""

    design_fts_expected_content = """/NumWaves       2
/NumContrasts   1

/Matrix
1 1
"""

    design_grp_expected_content = """/NumWaves       1
/NumPoints      3

/Matrix
1
1
1
"""
    for ii in ["mat", "con", "fts", "grp"]:
        assert tmpdir.join('design.' + ii).read() == eval(
            "design_" + ii + "_expected_content")



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..preprocess import ResponseSD


def test_ResponseSD_inputs():
    input_map = dict(
        algorithm=dict(
            argstr='%s',
            mandatory=True,
            position=1,
        ),
        args=dict(argstr='%s', ),
        bval_scale=dict(argstr='-bvalue_scaling %s', ),
        csf_file=dict(
            argstr='%s',
            extensions=None,
            position=-1,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        gm_file=dict(
            argstr='%s',
            extensions=None,
            position=-2,
        ),
        grad_file=dict(
            argstr='-grad %s',
            extensions=None,
            xor=['grad_fsl'],
        ),
        grad_fsl=dict(
            argstr='-fslgrad %s %s',
            xor=['grad_file'],
        ),
        in_bval=dict(extensions=None, ),
        in_bvec=dict(
            argstr='-fslgrad %s %s',
            extensions=None,
        ),
        in_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-5,
        ),
        in_mask=dict(
            argstr='-mask %s',
            extensions=None,
        ),
        max_sh=dict(
            argstr='-lmax %s',
            sep=',',
        ),
        mtt_file=dict(
            argstr='%s',
            extensions=None,
            position=-4,
        ),
        nthreads=dict(
            argstr='-nthreads %d',
            nohash=True,
        ),
        wm_file=dict(
            argstr='%s',
            extensions=None,
            position=-3,
            usedefault=True,
        ),
    )
    inputs = ResponseSD.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ResponseSD_outputs():
    output_map = dict(
        csf_file=dict(
            argstr='%s',
            extensions=None,
        ),
        gm_file=dict(
            argstr='%s',
            extensions=None,
        ),
        wm_file=dict(
            argstr='%s',
            extensions=None,
        ),
    )
    outputs = ResponseSD.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..minc import ToEcat


def test_ToEcat_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        ignore_acquisition_variable=dict(
            argstr='-ignore_acquisition_variable', ),
        ignore_ecat_acquisition_variable=dict(
            argstr='-ignore_ecat_acquisition_variable', ),
        ignore_ecat_main=dict(argstr='-ignore_ecat_main', ),
        ignore_ecat_subheader_variable=dict(
            argstr='-ignore_ecat_subheader_variable', ),
        ignore_patient_variable=dict(argstr='-ignore_patient_variable', ),
        ignore_study_variable=dict(argstr='-ignore_study_variable', ),
        input_file=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        no_decay_corr_fctr=dict(argstr='-no_decay_corr_fctr', ),
        output_file=dict(
            argstr='%s',
            extensions=None,
            genfile=True,
            hash_files=False,
            keep_extension=False,
            name_source=['input_file'],
            name_template='%s_to_ecat.v',
            position=-1,
        ),
        voxels_as_integers=dict(argstr='-label', ),
    )
    inputs = ToEcat.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_ToEcat_outputs():
    output_map = dict(output_file=dict(extensions=None, ), )
    outputs = ToEcat.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..meshfix import MeshFix


def test_MeshFix_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        cut_inner=dict(argstr='--cut-inner %d', ),
        cut_outer=dict(argstr='--cut-outer %d', ),
        decouple_inin=dict(argstr='--decouple-inin %d', ),
        decouple_outin=dict(argstr='--decouple-outin %d', ),
        decouple_outout=dict(argstr='--decouple-outout %d', ),
        dilation=dict(argstr='--dilate %d', ),
        dont_clean=dict(argstr='--no-clean', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        epsilon_angle=dict(argstr='-a %f', ),
        finetuning_distance=dict(
            argstr='%f',
            position=-2,
            requires=['finetuning_substeps'],
        ),
        finetuning_inwards=dict(
            argstr='--fineTuneIn ',
            position=-3,
            requires=['finetuning_distance', 'finetuning_substeps'],
        ),
        finetuning_outwards=dict(
            argstr='--fineTuneOut ',
            position=-3,
            requires=['finetuning_distance', 'finetuning_substeps'],
            xor=['finetuning_inwards'],
        ),
        finetuning_substeps=dict(
            argstr='%d',
            position=-1,
            requires=['finetuning_distance'],
        ),
        in_file1=dict(
            argstr='%s',
            extensions=None,
            mandatory=True,
            position=1,
        ),
        in_file2=dict(
            argstr='%s',
            extensions=None,
            position=2,
        ),
        join_closest_components=dict(
            argstr='-jc',
            xor=['join_closest_components'],
        ),
        join_overlapping_largest_components=dict(
            argstr='-j',
            xor=['join_closest_components'],
        ),
        laplacian_smoothing_steps=dict(argstr='--smooth %d', ),
        number_of_biggest_shells=dict(argstr='--shells %d', ),
        out_filename=dict(
            argstr='-o %s',
            extensions=None,
            genfile=True,
        ),
        output_type=dict(usedefault=True, ),
        quiet_mode=dict(argstr='-q', ),
        remove_handles=dict(argstr='--remove-handles', ),
        save_as_freesurfer_mesh=dict(
            argstr='--fsmesh',
            xor=['save_as_vrml', 'save_as_stl'],
        ),
        save_as_stl=dict(
            argstr='--stl',
            xor=['save_as_vrml', 'save_as_freesurfer_mesh'],
        ),
        save_as_vrml=dict(
            argstr='--wrl',
            xor=['save_as_stl', 'save_as_freesurfer_mesh'],
        ),
        set_intersections_to_one=dict(argstr='--intersect', ),
        uniform_remeshing_steps=dict(
            argstr='-u %d',
            requires=['uniform_remeshing_vertices'],
        ),
        uniform_remeshing_vertices=dict(
            argstr='--vertices %d',
            requires=['uniform_remeshing_steps'],
        ),
        x_shift=dict(argstr='--smooth %d', ),
    )
    inputs = MeshFix.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_MeshFix_outputs():
    output_map = dict(mesh_file=dict(extensions=None, ), )
    outputs = MeshFix.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..model import L2Model


def test_L2Model_inputs():
    input_map = dict(num_copes=dict(mandatory=True, ), )
    inputs = L2Model.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_L2Model_outputs():
    output_map = dict(
        design_con=dict(extensions=None, ),
        design_grp=dict(extensions=None, ),
        design_mat=dict(extensions=None, ),
    )
    outputs = L2Model.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..io import DataFinder


def test_DataFinder_inputs():
    input_map = dict(
        ignore_regexes=dict(),
        match_regex=dict(usedefault=True, ),
        max_depth=dict(),
        min_depth=dict(),
        root_paths=dict(mandatory=True, ),
        unpack_single=dict(usedefault=True, ),
    )
    inputs = DataFinder.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_DataFinder_outputs():
    output_map = dict()
    outputs = DataFinder.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from __future__ import unicode_literals
from ..developer import RandomVol


def test_RandomVol_inputs():
    input_map = dict(
        args=dict(argstr='%s', ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inField=dict(argstr='--inField %s', ),
        inLambda=dict(argstr='--inLambda %f', ),
        inMaximum=dict(argstr='--inMaximum %d', ),
        inMinimum=dict(argstr='--inMinimum %d', ),
        inSize=dict(argstr='--inSize %d', ),
        inSize2=dict(argstr='--inSize2 %d', ),
        inSize3=dict(argstr='--inSize3 %d', ),
        inSize4=dict(argstr='--inSize4 %d', ),
        inStandard=dict(argstr='--inStandard %d', ),
        null=dict(argstr='--null %s', ),
        outRand1=dict(
            argstr='--outRand1 %s',
            hash_files=False,
        ),
        xDefaultMem=dict(argstr='-xDefaultMem %d', ),
        xMaxProcess=dict(
            argstr='-xMaxProcess %d',
            usedefault=True,
        ),
        xPrefExt=dict(argstr='--xPrefExt %s', ),
    )
    inputs = RandomVol.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value
def test_RandomVol_outputs():
    output_map = dict(outRand1=dict(extensions=None, ), )
    outputs = RandomVol.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
